@@ -18,8 +18,8 @@
 ** the Free Software Foundation, 59 Temple Place - Suite 330,
 ** Boston, MA 02111-1307, USA.
 **
-**	This module contains the functions used to edit a program
-**	as well as ones to read and write programs and libraries
+**      This module contains the functions used to edit a program
+**      as well as ones to read and write programs and libraries
 **
 ** 05-Apr-2014 JGH: Can load Russell format BASIC programs.
 **
@@ -53,12 +53,12 @@
 #endif
 
 #define MARKERSIZE 4
-#define ENDMARKSIZE 8		/* Size of the sentinel value at the end of the program */
+#define ENDMARKSIZE 8           /* Size of the sentinel value at the end of the program */
 
-#define ACORN_ENDMARK 0xffu	/* Marker denoting end of Acorn Basic file */
+#define ACORN_ENDMARK 0xffu     /* Marker denoting end of Acorn Basic file */
 
-static byte *last_added;	/* Address of last line added to program */
-static boolean needsnumbers;	/* TRUE if a program need to be renumbered */
+static byte *last_added;        /* Address of last line added to program */
+static boolean needsnumbers;    /* TRUE if a program need to be renumbered */
 
 #ifdef BRANDYAPP
 extern const char *_binary_app_start;
@@ -71,10 +71,10 @@ typedef enum {TEXTFILE, BBCFILE, Z80FILE} filetype;
 /*
 ** The layout of a program in memory is as follows:
 **
-**	<start marker>
-**	<lines>
-**	<end marker>
-**	<heap>
+**      <start marker>
+**      <lines>
+**      <end marker>
+**      <heap>
 **
 ** <start marker> is the value 0xD7C1C7C5. This is used to decide whether the
 ** interpreter has been presented with a tokenised program or not. 'page'
@@ -91,11 +91,11 @@ typedef enum {TEXTFILE, BBCFILE, Z80FILE} filetype;
 **
 ** The format of each line of Basic is:
 **
-**	<line number>
-**	<length>
-**	<tokenised source>
-**	<tokenised executable line>
-**	<NUL>
+**      <line number>
+**      <length>
+**      <tokenised source>
+**      <tokenised executable line>
+**      <NUL>
 **
 ** <line number> and <length> are both two bytes long. Valid line numbers
 ** are in the range 0 to 65279 (0xFEFF). The length of a line can be up to
@@ -125,10 +125,10 @@ static byte startmark [STARTMARKSIZE] = {0xC5, 0xC7, 0xC1, 0xD7};
 ** with or to allow programs that drop off the end of their code to
 ** end gracefully
 */
-static byte endline [8] = {0, 0, 8, 0, 6, 0, BASIC_TOKEN_END, asc_NUL};
+static byte endline [8] = {0, 0, 8, 0, 6, 0, BASTOKEN_END, asc_NUL};
 
 void mark_end(byte *p) {
-  memcpy(p, endline, 8);	/* Place an 'END' token at the end of the program */
+  memcpy(p, endline, 8);        /* Place an 'END' token at the end of the program */
   save_lineno(p, ENDLINENO);
 }
 
@@ -236,9 +236,9 @@ static void clear_refs(void) {
     bp = basicvars.start;
     while (!AT_PROGEND(bp)) {
       clear_linerefs(bp);
-      bp+=get_linelen(bp);
+      bp+=GET_LINELEN(bp);
     }
-    lp = basicvars.installist;	/* Now clear the pointers in any installed libraries */
+    lp = basicvars.installist;  /* Now clear the pointers in any installed libraries */
     while (lp!=NIL) {
       bp = lp->libstart;
       while (!AT_PROGEND(bp)) {
@@ -259,32 +259,38 @@ static void clear_refs(void) {
 ** if new or replaces it if it already exists.
 */
 static void insert_line(byte *line) {
-  int32 lendiff, newline, newlength;
+  int32 newline = GET_LINENO(line);
+  int32 newlength = GET_LINELEN(line);
   byte *bp, *prev;
-  newline = get_lineno(line);
-  newlength = get_linelen(line);
-  if (last_added!=NIL && newline>=get_lineno(last_added))
+
+  if (last_added!=NIL && newline>=GET_LINENO(last_added))
     bp = last_added;
   else {
     bp = basicvars.start;
   }
   prev = NIL;
-  while (newline>=get_lineno(bp)) {	/* Work out where line goes */
+  while (newline>=GET_LINENO(bp)) {     /* Work out where line goes */
     prev = bp;
-    bp+=get_linelen(bp);
+    bp+=GET_LINELEN(bp);
   }
-  if (prev!=NIL && newline==get_lineno(prev)) {	/* Replacing a line */
-    lendiff = newlength-get_linelen(prev);
-    if (lendiff!=0) {	/* Old and new lines are not the same length */
-      if (basicvars.top+lendiff>=basicvars.himem) error(ERR_NOROOM);	/* No room for line */
+  if (prev!=NIL && newline==GET_LINENO(prev)) { /* Replacing a line */
+    int32 lendiff = newlength-GET_LINELEN(prev);
+    if (lendiff!=0) {   /* Old and new lines are not the same length */
+      if (basicvars.top+lendiff>=basicvars.himem) {
+        error(ERR_NOROOM);    /* No room for line */
+        return;
+      }
       memmove(prev+newlength, bp, basicvars.top-bp+ENDMARKSIZE);
       basicvars.top+=lendiff;
     }
     memmove(prev, line, newlength);
     last_added = prev;
   }
-  else {	/* Adding a line */
-    if (basicvars.top+newlength>=basicvars.himem) error(ERR_NOROOM);	/* No room for line */
+  else {        /* Adding a line */
+    if (basicvars.top+newlength>=basicvars.himem) {
+      error(ERR_NOROOM);    /* No room for line */
+      return;
+    }
     memmove(bp+newlength, bp, basicvars.top-bp+ENDMARKSIZE);
     memmove(bp, line, newlength);
     basicvars.top+=newlength;
@@ -298,11 +304,10 @@ static void insert_line(byte *line) {
 ** exists
 */
 static void delete_line(int32 line) {
-  int32 length;
-  byte *p;
-  p = find_line(line);
-  if (get_lineno(p)==line) {	/* Need an exact match. Cannot delete just anything... */
-    length = get_linelen(p);
+  byte *p = find_line(line);
+  
+  if (GET_LINENO(p)==line) {    /* Need an exact match. Cannot delete just anything... */
+    int32 length = GET_LINELEN(p);
     memmove(p, p+length, basicvars.top-p-length+ENDMARKSIZE);
     basicvars.top-=length;
     adjust_heaplimits();
@@ -319,10 +324,10 @@ void delete_range(int32 low, int32 high) {
   byte *lowline, *highline;
   if (low>high) return;
   lowline = find_line(low);
-  if (get_lineno(lowline)==ENDLINENO) return;	/* No lines are in the range to delete */
+  if (GET_LINENO(lowline)==ENDLINENO) return;   /* No lines are in the range to delete */
   clear_refs();
   highline = find_line(high);
-  if (get_lineno(highline)==high) highline+=get_linelen(highline);
+  if (GET_LINENO(highline)==high) highline+=GET_LINELEN(highline);
   memmove(lowline, highline, basicvars.top-highline+ENDMARKSIZE);
   basicvars.top-=(highline-lowline);
   adjust_heaplimits();
@@ -338,31 +343,31 @@ void delete_range(int32 low, int32 high) {
 ** pointers in the program are left pointing at the right lines.
 */
 void renumber_program(byte *progstart, int32 start, int32 step) {
-  byte *bp;
+  byte *bp = progstart;
   int32 lineno = start;
-  boolean ok;
-  bp = progstart;
+  
   while (!AT_PROGEND(bp) && start<=MAXLINENO) {
     resolve_linenums(bp);
-    bp+=get_linelen(bp);
+    bp+=GET_LINELEN(bp);
     lineno+=step;
   }
   if(lineno-step <= MAXLINENO) {
+    boolean ok;
     bp = progstart;
     while (!AT_PROGEND(bp) && start<=MAXLINENO) {
       save_lineno(bp, start);
       start+=step;
-      bp+=get_linelen(bp);
+      bp+=GET_LINELEN(bp);
     }
     ok = AT_PROGEND(bp);
-    if (!ok) {	/* Oops... Did not stop at end of program */
-      if (step!=1) { 	   /* Try to fix line numbers */
+    if (!ok) {  /* Oops... Did not stop at end of program */
+      if (step!=1) {       /* Try to fix line numbers */
         start = 1;
         bp = progstart;
         while (!AT_PROGEND(bp) && start<=MAXLINENO) {
           save_lineno(bp, start);
           start++;
-          bp+=get_linelen(bp);
+          bp+=GET_LINELEN(bp);
         }
       }
     }
@@ -370,7 +375,7 @@ void renumber_program(byte *progstart, int32 start, int32 step) {
   bp = progstart;
   while (!AT_PROGEND(bp)) {
     reset_linenums(bp);
-    bp+=get_linelen(bp);
+    bp+=GET_LINELEN(bp);
   }
   if(lineno-step > MAXLINENO) error(ERR_RENUMBER);
 }
@@ -403,13 +408,13 @@ static FILE *open_file(char *name) {
     strcpy(basicvars.filename, name); /* Reset */
     do {
       dest = basicvars.filename;
-      if (*srce!=',') {		/* Not got a null directory name */
+      if (*srce!=',') {         /* Not got a null directory name */
         while (*srce!=asc_NUL && *srce!=',') {
           *dest = *srce;
           dest++;
           srce++;
         }
-        if (*(srce-1)!=DIR_SEP) {	/* No separator after directory name */
+        if (*(srce-1)!=DIR_SEP) {       /* No separator after directory name */
           *dest = DIR_SEP;
           dest++;
         }
@@ -417,16 +422,16 @@ static FILE *open_file(char *name) {
       *dest = asc_NUL;
       strcat(basicvars.filename, name);
       handle = fopen(basicvars.filename, "rb");
-      if (handle!=NIL || *srce==asc_NUL) break;	/* File found or end of directory list reached */
+      if (handle!=NIL || *srce==asc_NUL) break; /* File found or end of directory list reached */
 #ifndef TARGET_RISCOS
       /* Add a .bbc suffix and try again */
       strcat(basicvars.filename, ".bbc");
       handle = fopen(basicvars.filename, "rb");
-      if (handle!=NIL || *srce==asc_NUL) break;	/* File found or end of directory list reached */
+      if (handle!=NIL || *srce==asc_NUL) break; /* File found or end of directory list reached */
 #endif
       srce++;
     } while (TRUE);
-    return handle;	/* Return file handle or NIL if file not found */
+    return handle;      /* Return file handle or NIL if file not found */
   }
 }
 
@@ -444,49 +449,55 @@ static FILE *open_file(char *name) {
 **
 */
 static int32 read_bbcfile(FILE *bbcfile, byte *base, byte *limit, int32 ftype) {
-  int length, count, zerolines = 0;
+  int length, zerolines = 0;
   byte line[INPUTLEN], *filebase;
   byte tokenline[MAXSTATELEN];
-  basicvars.linecount = 0;	/* Number of line being read from file */
+  basicvars.linecount = 0;      /* Number of line being read from file */
   filebase = base;
 
-  if (ftype == BBCFILE) count=fgetc(bbcfile);	/* Skip initial CR */
+  if (ftype == BBCFILE) (void)fgetc(bbcfile);   /* Skip initial CR */
   do {
+    int count;
     if (ftype == BBCFILE) {
-      line[0] = fgetc(bbcfile);			/* High order byte of line number */
-      if (line[0]==ACORN_ENDMARK) break;	/* Found 0xFF marking end of program so end */
-      line[1] = fgetc(bbcfile);			/* Low order byte of line number */
-      line[2] = length = fgetc(bbcfile);	/* Line length */
+      line[0] = fgetc(bbcfile);                 /* High order byte of line number */
+      if (line[0]==ACORN_ENDMARK) break;        /* Found 0xFF marking end of program so end */
+      line[1] = fgetc(bbcfile);                 /* Low order byte of line number */
+      line[2] = length = fgetc(bbcfile);        /* Line length */
     } else {
-      line[2] = length = fgetc(bbcfile);	/* Line length */
-      if (line[2]==0) break;			/* Found 0x00 at end of file so end */
-      line[1] = fgetc(bbcfile);			/* Low order byte of line number */
-      line[0] = fgetc(bbcfile);			/* High order byte of line number */
+      line[2] = length = fgetc(bbcfile);        /* Line length */
+      if (line[2]==0) break;                    /* Found 0x00 at end of file so end */
+      line[1] = fgetc(bbcfile);                 /* Low order byte of line number */
+      line[0] = fgetc(bbcfile);                 /* High order byte of line number */
     }
     count = fread(&line[3], sizeof(byte), length - 3, bbcfile);
-    if (count != length - 3) {			/* Incorrect number of bytes read */
+    if (count != length - 3) {                  /* Incorrect number of bytes read */
       fclose(bbcfile);
       bbcfile = NULL;
       error(ERR_READFAIL, basicvars.filename);
+      return 0;
     }
     basicvars.linecount++;
     length = reformat(line, tokenline, ftype);
-    if (length > 0) {				/* Line length is not zero so include line */
+    if (length > 0) {                           /* Line length is not zero so include line */
       if (base + length >= limit) {
         if (bbcfile) {
-	  fclose(bbcfile);
-	  bbcfile = NULL;
-	}
-	error(ERR_NOROOM);
+          fclose(bbcfile);
+          bbcfile = NULL;
+        }
+        error(ERR_NOROOM);
+        return 0;
       }
       memmove(base, tokenline, length);
-      if (get_lineno(tokenline) == 0) zerolines++;
+      if (GET_LINENO(tokenline) == 0) zerolines++;
       base+=length;
     }
   } while (!feof(bbcfile));
-  if (bbcfile) fclose(bbcfile);
+  fclose(bbcfile);
   basicvars.linecount = 0;
-  if (base + ENDMARKSIZE >= limit) error(ERR_NOROOM);
+  if (base + ENDMARKSIZE >= limit) {
+    error(ERR_NOROOM);
+    return 0;
+  }
   mark_end(base);
   if(zerolines > 1) {
     if (!basicvars.runflags.loadngo) emulate_printf("Line numbers added to program\r\n");
@@ -520,25 +531,38 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
 #endif
   fseek (textfile, 0, 0);
   tokenline[2] = 0;
-  if (fread(tokenline, 1, 3, textfile) < 3) error(ERR_CANTREAD);
+  if (fread(tokenline, 1, 3, textfile) < 3) {
+    error(ERR_CANTREAD);
+    return 0;
+  }
   matrixflags.scrunge = (tokenline[0] == 0x23 && tokenline[1] == 0xFA && tokenline[2] == 0xC8);
-  if (matrixflags.scrunge == 1 && basicvars.runflags.quitatend == 0) error(ERR_BADPROG);
+  if (matrixflags.scrunge == 1 && basicvars.runflags.quitatend == 0) {
+    error(ERR_BADPROG);
+    return 0;
+  }
   gzipped = (tokenline[0] == 0x1F && tokenline[1] == 0x8B && tokenline[2] == 8);
   if (gzipped) {
 #ifdef HAVE_ZLIB_H
     fclose (textfile);
     gzipfile = gzopen (basicvars.filename, "r");
-    if (gzipfile==NIL) error(ERR_FILEIO, basicvars.filename);
+    if (gzipfile==NIL) {
+      error(ERR_FILEIO, basicvars.filename);
+      return 0;
+    }
 #else
     error(ERR_NOGZIP);
+    return 0;
 #endif
   }
   else {
-    textfile = freopen(basicvars.filename, "r", textfile);	/* Close and reopen the file as a text file */
-    if (textfile==NIL) error(ERR_FILEIO, basicvars.filename);
+    textfile = freopen(basicvars.filename, "r", textfile);      /* Close and reopen the file as a text file */
+    if (textfile==NIL) {
+      error(ERR_FILEIO, basicvars.filename);
+      return 0;
+    }
   }
-  needsnumbers = FALSE;		/* This will be set by tokenise_line() above */
-  basicvars.linecount = 0;	/* Number of line being read from file */
+  needsnumbers = FALSE;         /* This will be set by tokenise_line() above */
+  basicvars.linecount = 0;      /* Number of line being read from file */
   filebase = base;
 #ifdef HAVE_ZLIB_H
   if (gzipped)
@@ -546,7 +570,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
   else
 #endif
   result = fgets(basicvars.stringwork, INPUTLEN, textfile);
-    if (result!=NIL && basicvars.stringwork[0]=='#') {	/* Ignore first line if it starts with a '#' */
+    if (result!=NIL && basicvars.stringwork[0]=='#') {  /* Ignore first line if it starts with a '#' */
     basicvars.runflags.quitatend=basicvars.runflags.loadngo;
 #ifdef HAVE_ZLIB_H
     if (gzipped)
@@ -567,13 +591,13 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
     basicvars.stringwork[length] = asc_NUL;
     tokenize(basicvars.stringwork, tokenline, HASLINE, FALSE);
 //    tokenize(basicvars.stringwork, tokenline, HASLINE);
-    if (get_lineno(tokenline)==NOLINENO) {
-      save_lineno(tokenline, 0);	/* Otherwise renumber goes a bit funny */
+    if (GET_LINENO(tokenline)==NOLINENO) {
+      save_lineno(tokenline, 0);        /* Otherwise renumber goes a bit funny */
       needsnumbers = TRUE;
     }
-    length = get_linelen(tokenline);
-    if (length>0) {	/* Line length is not zero so include line */
-      if (base+length>=limit) {	/* No room left */
+    length = GET_LINELEN(tokenline);
+    if (length>0) {     /* Line length is not zero so include line */
+      if (base+length>=limit) { /* No room left */
 #ifdef HAVE_ZLIB_H
         if (gzipped)
           gzclose (gzipfile);
@@ -582,6 +606,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
         fclose(textfile);
         basicvars.misc_flags.badprogram=1; /* The program is incomplete, thus corrupt */
         error(ERR_NOROOM);
+        return 0;
       }
       memmove(base, tokenline, length);
       base+=length;
@@ -600,9 +625,12 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
 #endif
   fclose(textfile);
   basicvars.linecount = 0;
-  if (base+ENDMARKSIZE>=limit) error(ERR_NOROOM);
+  if (base+ENDMARKSIZE>=limit) {
+    error(ERR_NOROOM);
+    return 0;
+  }
   mark_end(base);
-  if (needsnumbers) {		/* Line numbers are missing */
+  if (needsnumbers) {           /* Line numbers are missing */
     if (!basicvars.runflags.loadngo) emulate_printf("Line numbers added to program\r\n");
     renumber_program(filebase, 1, 1);
   }
@@ -647,11 +675,11 @@ static int32 read_textblock(byte *base, byte *limit, boolean silent) {
   blockread (tokenline, 1, 3);
   matrixflags.scrunge = (tokenline[0] == 0x23 && tokenline[1] == 0xFA && tokenline[2] == 0xC8);
   blockptr = 0;  /* Close and reopen the file as a text file */
-  needsnumbers = FALSE;		/* This will be set by tokenise_line() above */
-  basicvars.linecount = 0;	/* Number of line being read from file */
+  needsnumbers = FALSE;         /* This will be set by tokenise_line() above */
+  basicvars.linecount = 0;      /* Number of line being read from file */
   filebase = base;
   result = blockgets(basicvars.stringwork, INPUTLEN); // result = fgets(basicvars.stringwork, INPUTLEN, textfile);
-  if (result!=NIL && basicvars.stringwork[0]=='#') {	/* Ignore first line if it starts with a '#' */
+  if (result!=NIL && basicvars.stringwork[0]=='#') {    /* Ignore first line if it starts with a '#' */
   result = blockgets(basicvars.stringwork, INPUTLEN); // result = fgets(basicvars.stringwork, INPUTLEN, textfile);
   }
   while (result!=NIL) {
@@ -664,14 +692,15 @@ static int32 read_textblock(byte *base, byte *limit, boolean silent) {
     length++;
     basicvars.stringwork[length] = asc_NUL;
     tokenize(basicvars.stringwork, tokenline, HASLINE, FALSE);
-    if (get_lineno(tokenline)==NOLINENO) {
-      save_lineno(tokenline, 0);	/* Otherwise renumber goes a bit funny */
+    if (GET_LINENO(tokenline)==NOLINENO) {
+      save_lineno(tokenline, 0);        /* Otherwise renumber goes a bit funny */
       needsnumbers = TRUE;
     }
-    length = get_linelen(tokenline);
-    if (length>0) {	/* Line length is not zero so include line */
-      if (base+length>=limit) {	/* No room left */
+    length = GET_LINELEN(tokenline);
+    if (length>0) {     /* Line length is not zero so include line */
+      if (base+length>=limit) { /* No room left */
         error(ERR_NOROOM);
+        return 0;
       }
       memmove(base, tokenline, length);
       base+=length;
@@ -679,9 +708,12 @@ static int32 read_textblock(byte *base, byte *limit, boolean silent) {
     result = blockgets(basicvars.stringwork, INPUTLEN); // result = fgets(basicvars.stringwork, INPUTLEN, textfile);
   }
   basicvars.linecount = 0;
-  if (base+ENDMARKSIZE>=limit) error(ERR_NOROOM);
+  if (base+ENDMARKSIZE>=limit) {
+    error(ERR_NOROOM);
+    return 0;
+  }
   mark_end(base);
-  if (needsnumbers) {		/* Line numbers are missing */
+  if (needsnumbers) {           /* Line numbers are missing */
     renumber_program(filebase, 1, 1);
   }
   return ALIGN(base-filebase+ENDMARKSIZE);
@@ -708,8 +740,8 @@ static filetype identify(FILE *thisfile, char *name) {
   int32 ptr=0,flag=1;
 
   count = fread(basicvars.stringwork, sizeof(byte), 260, thisfile);
-  fseek(thisfile, 0, SEEK_SET);				/* Rewind to start */
-  if (count < 2) return TEXTFILE;			/* Too short to be tokenised */
+  fseek(thisfile, 0, SEEK_SET);                         /* Rewind to start */
+  if (count < 2) return TEXTFILE;                       /* Too short to be tokenised */
 
   /* Try to identify some pathological cases. Read entire buffer (up to count)
    * and if everything, excluding strings in quotes, is 10, 13 or 32-126 then
@@ -719,9 +751,9 @@ static filetype identify(FILE *thisfile, char *name) {
    * a text file.
    */
   while (ptr < count) {
-    if ((basicvars.stringwork[ptr] == 34) && (ptr < count-1)) { /* " */
+    if ((ptr < count-1) && (basicvars.stringwork[ptr] == 34)) { /* " */
       ptr++;
-      while ((basicvars.stringwork[ptr] != 34) && (ptr < count)) ptr++;
+      while ((ptr < count) && (basicvars.stringwork[ptr] != 34)) ptr++;
     }
     if ((ptr < count) && basicvars.stringwork[ptr] != asc_CR && basicvars.stringwork[ptr] != asc_LF)
       if (basicvars.stringwork[ptr] < 32 || basicvars.stringwork[ptr] > 126) flag=0;
@@ -729,16 +761,16 @@ static filetype identify(FILE *thisfile, char *name) {
   }
   if (flag) return TEXTFILE;
 
-  if (basicvars.stringwork[0] == asc_CR)			/* Simple check for Acorn format */
+  if (basicvars.stringwork[0] == asc_CR)                        /* Simple check for Acorn format */
     if ((unsigned char)basicvars.stringwork[3] > 3)
       if (basicvars.stringwork[(unsigned char)basicvars.stringwork[3]] == asc_CR)
         return BBCFILE;
 
-  if ((unsigned char)basicvars.stringwork[0] > 3)	/* Simple check for Russell format */
+  if ((unsigned char)basicvars.stringwork[0] > 3)       /* Simple check for Russell format */
     if (basicvars.stringwork[(unsigned char)basicvars.stringwork[0]-1] == asc_CR)
       return Z80FILE;
 
-  return TEXTFILE;					/* Everything else is text */
+  return TEXTFILE;                                      /* Everything else is text */
 
 }
 
@@ -752,15 +784,21 @@ static filetype identify(FILE *thisfile, char *name) {
 void read_basic(char *name) {
   FILE *loadfile;
   int32 length, ftype;
-  if (strlen(name) > (FNAMESIZE - 1)) error(ERR_INVALIDFNAME);
+  if (strlen(name) > (FNAMESIZE - 1)) {
+    error(ERR_INVALIDFNAME);
+    return;
+  }
   loadfile = open_file(name);
-  if (loadfile==NIL) error(ERR_NOTFOUND, name);
+  if (loadfile==NIL) {
+    error(ERR_NOTFOUND, name);
+    return;
+  }
   last_added = NIL;
-  if ((ftype=identify(loadfile, name)) != TEXTFILE) {	/* Tokenised BBC BASIC file */
+  if ((ftype=identify(loadfile, name)) != TEXTFILE) {   /* Tokenised BBC BASIC file */
     clear_program();
     length = read_bbcfile(loadfile, basicvars.top, basicvars.himem, ftype);
   }
-  else {						/* Plain text */
+  else {                                                /* Plain text */
     clear_program();
     length = read_textfile(loadfile, basicvars.top, basicvars.himem, basicvars.runflags.loadngo);
   }
@@ -792,15 +830,18 @@ void read_basic_block() {
 static void link_library(char *name, byte *base, int32 size, boolean onheap) {
   library *lp;
   int n;
-  if (onheap) {		/* Library is held on Basic heap */
-    lp = allocmem(sizeof(library), 1);	/* Add library to list */
-    lp->libname = allocmem(strlen(name)+1, 1);	/* +1 for NULL at end */
+  if (onheap) {         /* Library is held on Basic heap */
+    lp = allocmem(sizeof(library), 1);  /* Add library to list */
+    lp->libname = allocmem(strlen(name)+1, 1);  /* +1 for NULL at end */
     lp->libflink = basicvars.liblist;
     basicvars.liblist = lp;
   }
-  else {	/* Library is held in permanent memory */
+  else {        /* Library is held in permanent memory */
     lp = malloc(sizeof(library));
-    if (lp==NIL) error(ERR_LIBSIZE, name);	/* Run out of memory */
+    if (lp==NIL) {
+      error(ERR_LIBSIZE, name);      /* Run out of memory */
+      return;
+    }
     lp->libname = malloc(strlen(name)+1);
     lp->libflink = basicvars.installist;
     basicvars.installist = lp;
@@ -822,14 +863,17 @@ static void read_bbclib(FILE *libfile, char *name, boolean onheap, int32 ftype)
   byte *base;
   base = basicvars.vartop;
   size = read_bbcfile(libfile, base, basicvars.stacktop.bytesp, ftype);
-  if (onheap) {	/* Adjust heap pointers as library is on the heap */
+  if (onheap) { /* Adjust heap pointers as library is on the heap */
     basicvars.vartop = basicvars.vartop+size;
     basicvars.stacklimit.bytesp = basicvars.vartop+STACKBUFFER;
   }
-  else {	/* Library being loaded via 'INSTALL' - Move to permanent memory */
+  else {        /* Library being loaded via 'INSTALL' - Move to permanent memory */
     byte *installbase;
     installbase = malloc(size);
-    if (installbase==NIL) error(ERR_LIBSIZE, name);
+    if (installbase==NIL) {
+      error(ERR_LIBSIZE, name);
+      return;
+    }
     memmove(installbase, base, size);
     base = installbase;
 #ifdef DEBUG
@@ -858,10 +902,13 @@ static void read_textlib(FILE *libfile, char *name, boolean onheap) {
     basicvars.vartop+=size;
     basicvars.stacklimit.bytesp = basicvars.vartop+STACKBUFFER;
   }
-  else {	/* Library being loaded via 'INSTALL' - Move to permanent memory */
+  else {        /* Library being loaded via 'INSTALL' - Move to permanent memory */
     byte *installbase;
     installbase = malloc(size);
-    if (installbase==NIL) error(ERR_LIBSIZE, name);
+    if (installbase==NIL) {
+      error(ERR_LIBSIZE, name);
+      return;
+    }
     memmove(installbase, base, size);
     base = installbase;
 #ifdef DEBUG
@@ -885,22 +932,28 @@ void read_library(char *name, boolean onheap) {
   FILE *libfile;
   int32 ftype;
 
-  if (strlen(name) > (FNAMESIZE - 1)) error(ERR_INVALIDFNAME);
-  if (onheap)	/* Check if library has already been loaded */
+  if (strlen(name) > (FNAMESIZE - 1)) {
+    error(ERR_INVALIDFNAME);
+    return;
+  }
+  if (onheap)   /* Check if library has already been loaded */
     lp = basicvars.liblist;
   else {
     lp = basicvars.installist;
   }
   while (lp != NIL && strcmp(lp->libname, name) != 0) lp = lp->libflink;
-  if (lp != NIL) {	/* Library has already been loaded */
+  if (lp != NIL) {      /* Library has already been loaded */
     error(WARN_LIBLOADED, name);
     return;
   }
   libfile = open_file(name);
-  if (libfile == NIL) error(ERR_NOLIB, name);		/* Cannot find library */
-  if ((ftype=identify(libfile, name)) != TEXTFILE)	/* Reading a BBC BASIC tokenised library */
+  if (libfile == NIL) {
+    error(ERR_NOLIB, name);           /* Cannot find library */
+    return;
+  }
+  if ((ftype=identify(libfile, name)) != TEXTFILE)      /* Reading a BBC BASIC tokenised library */
     read_bbclib(libfile, name, onheap, ftype);
-  else {						/* Reading a library in plain text form */
+  else {                                                /* Reading a library in plain text form */
     read_textlib(libfile, name, onheap);
   }
 }
@@ -921,17 +974,21 @@ void write_text(char *name, FILE *fhandle) {
   } else {
     savefile = fopen(name, "w");
   }
-  if (savefile==NIL) error(ERR_NOTCREATED, name);
+  if (savefile==NIL) {
+    error(ERR_NOTCREATED, name);
+    return;
+  }
   bp = basicvars.start;
   while (!AT_PROGEND(bp)) {
     expand(bp, basicvars.stringwork);
     x = fputs(basicvars.stringwork, savefile);
     if (x!=EOF) x = fputc('\n', savefile);
-    if (x==EOF) {	/* Error occured writing to file */
+    if (x==EOF) {       /* Error occured writing to file */
       fclose(savefile);
       error(ERR_WRITEFAIL, name);
+      return;
     }
-    bp+=get_linelen(bp);
+    bp+=GET_LINELEN(bp);
   }
   fclose(savefile);
 #ifdef TARGET_RISCOS
@@ -947,11 +1004,14 @@ void write_text(char *name, FILE *fhandle) {
 ** 'edit_line' is the main line editing routine.
 */
 void edit_line(void) {
-  if (basicvars.misc_flags.badprogram) error(ERR_BADPROG);
+  if (basicvars.misc_flags.badprogram) {
+    error(ERR_BADPROG);
+    return;
+  }
   clear_refs();
-  basicvars.misc_flags.validsaved = FALSE;	/* If program is edited mark save area contents as bad */
-  if (isempty(thisline))			/* Empty line = delete line */
-    delete_line(get_lineno(thisline));
+  basicvars.misc_flags.validsaved = FALSE;      /* If program is edited mark save area contents as bad */
+  if (isempty(thisline))                        /* Empty line = delete line */
+    delete_line(GET_LINENO(thisline));
   else {
     insert_line(thisline);
   }
