@@ -40,6 +40,7 @@
 #include "evaluate.h"
 #include "miscprocs.h"
 #include "keyboard.h"
+#include "net.h"
 #ifdef USE_SDL
 #include "graphsdl.h"
 #endif
@@ -67,8 +68,8 @@
 */
 
 #define COPYRIGHT "Matrix Brandy " BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL " is free software;  you can redistribute it and/or modify\r\n" \
-	"it under the  terms of the  GNU General Public License as published by the Free\r\n" \
-	"Software  Foundation.   See  the  file  COPYING for further details.\r\n"
+        "it under the  terms of the  GNU General Public License as published by the Free\r\n" \
+        "Software  Foundation.   See  the  file  COPYING for further details.\r\n"
 
 #define MAXCALLDEPTH 10      /* Maximum no. of entries printed in PROC/FN traceback */
 
@@ -103,14 +104,18 @@ static char errortext[200];     /* Copy of text of last error for REPORT */
 ** well as dealing with the signal
 */
 static void handle_signal(int signo) {
+  DEBUGFUNCMSGIN;
   switch (signo) {
 #ifndef TARGET_MINGW
   case SIGUSR1:
+    DEBUGFUNCMSGOUT;
     return;
   case SIGUSR2:
+    DEBUGFUNCMSGOUT;
     return;
 #ifdef SIGPIPE
   case SIGPIPE:
+    DEBUGFUNCMSGOUT;
     return;
 #endif
 #endif
@@ -122,33 +127,38 @@ static void handle_signal(int signo) {
 #if defined(TARGET_MINGW) || defined(TARGET_RISCOS)
     (void) signal(SIGINT, handle_signal);
 #endif
+    DEBUGFUNCMSGOUT;
     return;
   case SIGFPE:
 #ifdef TARGET_MINGW
     (void) signal(SIGFPE, handle_signal);
 #endif
+    DEBUGFUNCMSGOUT;
     error(ERR_ARITHMETIC);
   case SIGSEGV:
 #ifdef TARGET_MINGW
     (void) signal(SIGSEGV, handle_signal);
 #endif
+    DEBUGFUNCMSGOUT;
     error(ERR_ADDREXCEPT);
   case SIGABRT:
 #ifdef TARGET_MINGW
     (void) signal(SIGABRT, handle_signal);
 #endif
+    DEBUGFUNCMSGOUT;
     error(ERR_ADDREXCEPT);
 #if defined(TARGET_UNIX) | defined(TARGET_MACOSX)
   case SIGCONT:
 #ifdef TARGET_MINGW
     (void) signal(SIGCONT, handle_signal);
 #endif
-//    kbd_init();		// shouldn't be re-init'ing kbd in middle of a signal
+//    kbd_init();               // shouldn't be re-init'ing kbd in middle of a signal
     return;
 #endif
   default:
     error(ERR_UNKNOWN, signo);
   }
+  DEBUGFUNCMSGOUT;
 }
 
 #ifdef TARGET_MINGW
@@ -160,11 +170,10 @@ static DWORD watch_escape(LPVOID unused) {
   boolean alreadyraised = FALSE;
 
   while (1) {
-//  if (GetAsyncKeyState(VK_ESCAPE) < 0)
     if (kbd_escpoll()) {
       if (!alreadyraised && (GetForegroundWindow() == GetConsoleWindow())) {
-        raise(SIGINT);
         alreadyraised = TRUE;
+        raise(SIGINT);
       }
     }
     else
@@ -192,6 +201,7 @@ void watch_signals(void) {
 ** to 'false'
 */
 void init_errors(void) {
+  DEBUGFUNCMSGIN;
   errortext[0] = asc_NUL;
   if (basicvars.misc_flags.trapexcp) {  /* Want program to trap exceptions */
 #if defined(TARGET_MINGW) || defined(TARGET_DJGPP) || defined(__TARGET_SCL__)
@@ -247,6 +257,7 @@ void init_errors(void) {
 
 #endif /* TARGET_MINGW | TARGET_DJGPP */
   }
+  DEBUGFUNCMSGOUT;
 }
 
 /*
@@ -255,6 +266,7 @@ void init_errors(void) {
 ** safe side
 */
 void restore_handlers(void) {
+  DEBUGFUNCMSGIN;
   if (basicvars.misc_flags.trapexcp) {
     (void) signal(SIGFPE, SIG_DFL);
     (void) signal(SIGSEGV, SIG_DFL);
@@ -270,12 +282,14 @@ void restore_handlers(void) {
     if (sigintthread != NULL) TerminateThread(sigintthread, 0);
 #endif
   }
+  DEBUGFUNCMSGOUT;
 }
 
 /*
 ** 'announce' prints out the start messages for the interpreter
 */
 void announce(void) {
+  DEBUGFUNCMSGIN;
 #ifdef BRANDY_BANNER_MINIMAL
   emulate_printf("\nMatrix Brandy ");
   if ((basicvars.himem-basicvars.page) > (98304*1024))
@@ -289,13 +303,16 @@ void announce(void) {
 #else
   emulate_printf("\n%s\r\n\nStarting with " FMT_SZD " bytes free\r\n\n", IDSTRING, basicvars.himem-basicvars.page);
 #endif /* BRANDY_BANNER_MINIMAL */
+#ifndef NONET
+  if (matrixflags.checknewver) {
+    if (checkfornewer()) emulate_printf("A newer version is available!\r\n\n");
+  }
+#endif /* NONET */
 #ifdef DEBUG
-#ifdef BRANDY_GITCOMMIT
-  emulate_printf("Git commit %s on branch %s (%s)\r\n\n", BRANDY_GITCOMMIT, BRANDY_GITBRANCH, BRANDY_GITDATE);
-#endif
   emulate_printf("Basicvars is at &" FMT_SZX ", tokenised line is at &" FMT_SZX "\r\nWorkspace is at &" FMT_SZX ", size is " FMT_SZX "\r\nPAGE = &" FMT_SZX ", HIMEM = &" FMT_SZX "\r\n",
    &basicvars, &thisline, basicvars.workspace, basicvars.worksize, basicvars.page, basicvars.himem);
 #endif /*DEBUG*/
+  DEBUGFUNCMSGOUT;
 }
 
 /*
@@ -303,6 +320,7 @@ void announce(void) {
 ** and debugging options in effect
 */
 void show_options(int32 showextra) {
+  DEBUGFUNCMSGIN;
 #ifdef BRANDY_GITCOMMIT
   emulate_printf("%s\r\n  Git commit %s on branch %s (%s)\r\n\n", IDSTRING, BRANDY_GITCOMMIT, BRANDY_GITBRANCH, BRANDY_GITDATE);
 #else
@@ -330,9 +348,11 @@ void show_options(int32 showextra) {
     emulate_printf("  Show PROC/FN call trace on error: %s\r\n\n", basicvars.traces.backtrace ? "Yes" : "No");
     if (basicvars.tracehandle != 0) emulate_printf("Trace output is being written to a file\r\n\n");
   }
+  DEBUGFUNCMSGOUT;
 }
 
 void show_help(void) {
+  DEBUGFUNCMSGIN;
   printf("%s\n\n%s\nThe command syntax is:\n\n", IDSTRING, COPYRIGHT);
 #ifdef BRANDYAPP
   printf("    thisapp [<options>]\n\n");
@@ -353,6 +373,7 @@ void show_help(void) {
   printf("  -tek           Enable Tek graphics (on compatible builds)\n");
 #endif
 #ifndef BRANDYAPP
+  printf("  -nocheck       Skip new version check on immediate mode startup\n");
   printf("  -path <list>   Look for programs and libraries in directories in list <list>\n");
   printf("  -load <file>   Load Basic program <file> when the interpreter starts\n");
   printf("  -chain <file>  Run Basic program <file> and stay in interpreter when it ends\n");
@@ -362,6 +383,10 @@ void show_help(void) {
   printf("  -strict        'Unsupported features' generate errors\n");
 #else
   printf("  -ignore        Ignore 'unsupported feature' where possible\n");
+#endif
+#ifndef TARGET_RISCOS
+  printf("  -nostar        Do not check OSCLI for internal *-commands, instead pass all\n");
+  printf("                 commands to the underlying operating system.\n");
 #endif
   printf("  --             Subsequent options are passed to Basic program\n");
   printf("  <file>         Run Basic program <file> and leave interpreter when it ends\n\n");
@@ -369,6 +394,7 @@ void show_help(void) {
   printf("Basic program files may be gzipped.\n\n");
 #endif
 #endif /* BRANDYAPP */
+  DEBUGFUNCMSGOUT;
 }
 
 static detail badcmdtable [] = {
@@ -387,6 +413,8 @@ static detail badcmdtable [] = {
 */
 void cmderror(int32 errnumber, ...) {
   va_list parms;
+
+  DEBUGFUNCMSGIN;
   va_start(parms, errnumber);
   switch (badcmdtable[errnumber].parmtype) {
   case INTEGER:
@@ -402,6 +430,7 @@ void cmderror(int32 errnumber, ...) {
     break;
   }
   va_end(parms);
+  DEBUGFUNCMSGOUT;
 }
 
 /*
@@ -421,7 +450,7 @@ static detail errortable [] = {
 /* ERR_NOGRAPHICS */    {FATAL,    NOPARM,   0, "This version of the interpreter does not support graphics"},
 /* ERR_NOVDUCMDS */     {FATAL,    NOPARM,   0, "VDU commands cannot be used as output is not to a screen"},
 /* ERR_SYNTAX */        {NONFATAL, NOPARM,  16, "Syntax error"},
-/* ERR_SILLY */	        {NONFATAL, NOPARM,   0, "Silly!"},
+/* ERR_SILLY */         {NONFATAL, NOPARM,   0, "Silly!"},
 /* ERR_BADPROG */       {NONFATAL, NOPARM,   0, "Bad program"},
 /* ERR_ESCAPE */        {NONFATAL, NOPARM,  17, "Escape"},
 /* ERR_STOP */          {FATAL,    NOPARM,   0, "STOP"},
@@ -502,7 +531,6 @@ static detail errortable [] = {
 /* ERR_LOCAL */         {NONFATAL, NOPARM,  12, "LOCAL found outside a PROC or FN"},
 /* ERR_DATA */          {NONFATAL, NOPARM,  42, "There are no more 'DATA' statements to read"},
 /* ERR_NOROOM */        {FATAL,    NOPARM,   0, "The interpreter has run out of memory"},
-/* ERR_RECLIMIT */      {FATAL,    NOPARM,   0, "Exceeded interpreter recursion depth"},
 /* ERR_WHENCOUNT */     {NONFATAL, NOPARM,  47, "'CASE' statement has too many 'WHEN' clauses"},
 /* ERR_SYSCOUNT */      {NONFATAL, NOPARM,  51, "'SYS' statement has too many parameters"},
 /* ERR_STACKFULL */     {FATAL,    NOPARM,   0, "Arithmetic stack overflow"},
@@ -580,10 +608,10 @@ static detail errortable [] = {
 /* ERR_BADSYNTAX */     {NONFATAL, STRING, 220, "Syntax: %s"},
 //
 // Network errors
-/* ERR_NET_CONNREFUSED*/{NONFATAL, NOPARM, 165, "Connection refused"},			// 'No reply'
-/* ERR_NET_NOTFOUND */  {NONFATAL, NOPARM, 213, "Host not found"},			// 'Disk not present'
+/* ERR_NET_CONNREFUSED*/{NONFATAL, NOPARM, 165, "Connection refused"},                  // 'No reply'
+/* ERR_NET_NOTFOUND */  {NONFATAL, NOPARM, 213, "Host not found"},                      // 'Disk not present'
 /* ERR_NET_MAXSOCKETS */{NONFATAL, NOPARM, 192, "The maximum allowed number of sockets is already open"},
-/* ERR_NET_NOTSUPP */   {NONFATAL, NOPARM, 157, "Network operation not supported"},	// 'Unsupported operation'
+/* ERR_NET_NOTSUPP */   {NONFATAL, NOPARM, 157, "Network operation not supported"},     // 'Unsupported operation'
 /* ERR_NO_RPI_GPIO */   {NONFATAL, NOPARM, 510, "Raspberry Pi GPIO not available"},
 //
 // Dynamic Linker errors
@@ -606,13 +634,21 @@ static detail errortable [] = {
 */
 static char *find_libname(byte *p) {
   library *lp;
-  if (p>=basicvars.page && p<basicvars.top) return NIL;
+
+  DEBUGFUNCMSGIN;
+  if (p>=basicvars.page && p<basicvars.top) {
+    DEBUGFUNCMSGOUT;
+    return NIL;
+  }
   lp = find_library(p);
+  DEBUGFUNCMSGOUT;
   return lp==NIL ? NIL : lp->libname;
 }
 
 static char *procfn(char *name) {
-  return *CAST(name, byte *)==BASIC_TOKEN_PROC ? "PROC" : "FN";
+  DEBUGFUNCMSGIN;
+  DEBUGFUNCMSGOUT;
+  return *CAST(name, byte *)==BASTOKEN_PROC ? "PROC" : "FN";
 }
 
 /*
@@ -621,10 +657,9 @@ static char *procfn(char *name) {
 ** error is just a warning, that is, iserror is FALSE
 */
 static void print_details(boolean iserror) {
-  int32 count;
   fnprocinfo *p;
-  byte *lp;
-  char *libname;
+
+  DEBUGFUNCMSGIN;
   basicvars.printcount = 0;             /* Reset no. of chars Basic has printed on line to zero */
   if (basicvars.error_line==0) {        /* Error occured when dealing with the command line */
     if (basicvars.linecount==0) {
@@ -635,6 +670,7 @@ static void print_details(boolean iserror) {
     }
   }
   else {        /* Error occured in running program */
+    char *libname;
     if (basicvars.procstack==NIL) {
       emulate_printf("\r\n%s at line %d", errortext, basicvars.error_line);
     } else {
@@ -651,11 +687,11 @@ static void print_details(boolean iserror) {
     }
     if (iserror && basicvars.traces.backtrace && basicvars.procstack!=NIL) {
 /* Print a stack backtrace */
-      count = 0;
+      int32 count = 0;
       p = basicvars.procstack;
       emulate_printf("PROC/FN call trace:\r\n");
       while (p!=NIL && count<MAXCALLDEPTH) {
-        lp = find_linestart(p->retaddr);
+        byte *lp = find_linestart(p->retaddr);
         if (lp!=NIL)    /* Line was in the program or a library */
           libname = find_libname(p->retaddr);
         else if (basicvars.curcount>0) {        /* In EVAL or READ */
@@ -670,7 +706,7 @@ static void print_details(boolean iserror) {
            procfn(p->fnprocname), p->fnprocname+1);
         else {
           emulate_printf("  %s%s was called from line %d",
-           procfn(p->fnprocname), p->fnprocname+1, get_lineno(lp));
+           procfn(p->fnprocname), p->fnprocname+1, GET_LINENO(lp));
         }
         p = p->lastcall;
         if (p==NIL)
@@ -687,6 +723,7 @@ static void print_details(boolean iserror) {
       }
     }
   }
+  DEBUGFUNCMSGOUT;
 }
 
 /*
@@ -724,6 +761,7 @@ static void print_details(boolean iserror) {
 ** error handler.
 */
 static void handle_error(errortype severity) {
+  DEBUGFUNCMSGIN;
 #ifdef DEBUG
   if (basicvars.debug_flags.debug) {
     fprintf(stderr, "Error in Basic program - %s at line %d\n", errortext, basicvars.error_line);
@@ -746,6 +784,7 @@ static void handle_error(errortype severity) {
 #ifdef DEBUG
       if (basicvars.debug_flags.debug) fprintf(stderr, "About to siglongjmp(*basicvars.local_restart,1), local_restart = %p\n", basicvars.local_restart);
 #endif
+      DEBUGFUNCMSGOUT;
       siglongjmp(*basicvars.local_restart, 1);
     } else {      /* Trapped via 'ON ERROR' - Reset everything and return to main interpreter loop */
       basicvars.procstack = NIL;
@@ -754,6 +793,7 @@ static void handle_error(errortype severity) {
 #ifdef DEBUG
       if (basicvars.debug_flags.debug) fprintf(stderr, "About to siglongjmp(*basicvars.error_restart,1), localrestart = %p\n", basicvars.error_restart);
 #endif
+      DEBUGFUNCMSGOUT;
       siglongjmp(basicvars.error_restart, 1);      /* Branch back to the main interpreter loop */
     }
   }
@@ -772,6 +812,7 @@ static void handle_error(errortype severity) {
     basicvars.gosubstack = NIL;
     basicvars.recdepth = 0;
     clear_stack();              /* Clear the stack on an unhandled error */
+    DEBUGFUNCMSGOUT;
     siglongjmp(basicvars.restart, 1);  /* Error - branch to main interpreter loop */
   }
 }
@@ -803,6 +844,7 @@ void error(int32 errnumber, ...) {
   *collapse="bork";
 #endif
 
+  DEBUGFUNCMSGIN;
 #ifdef USE_SDL
   while (matrixflags.videothreadbusy) usleep(1000);
   hide_cursor();
@@ -812,10 +854,10 @@ void error(int32 errnumber, ...) {
     errnumber = ERR_BROKEN;
   }
 
-  if (errnumber == ERR_ESCAPE) kbd_escack();				/* Acknowledge and process Escape effects */
+  if (errnumber == ERR_ESCAPE) kbd_escack();                            /* Acknowledge and process Escape effects */
 
 #ifdef USE_SDL
-  if (2 == get_refreshmode()) star_refresh(1);	/* Re-enable Refresh if stopped using *Refresh OnError */
+  if (2 == get_refreshmode()) star_refresh(1);  /* Re-enable Refresh if stopped using *Refresh OnError */
 #endif
   va_start(parms, errnumber);
   vsprintf(errortext, errortable[errnumber].msgtext, parms);
@@ -830,7 +872,7 @@ void error(int32 errnumber, ...) {
     if (badline==NIL)   /* Error did not occur in program - Assume it was in the command line */
       basicvars.error_line = 0;
     else {      /* Error occured in running program */
-      basicvars.error_line = get_lineno(badline);
+      basicvars.error_line = GET_LINENO(badline);
     }
   }
   if (errortable[errnumber].severity<=WARNING &&   /* Error message is just a warning */
@@ -840,15 +882,19 @@ void error(int32 errnumber, ...) {
   else {
     handle_error(errortable[errnumber].severity);
   }
+  DEBUGFUNCMSGOUT;
 }
 
 /*
 ** 'get_lasterror' is used to return the text of the last error message
 */
 char *get_lasterror(void) {
-  if (errortext[0]==asc_NUL)
+  DEBUGFUNCMSGIN;
+  if (errortext[0]==asc_NUL) {
+    DEBUGFUNCMSGOUT;
     return COPYRIGHT;
-  else {
+  } else {
+    DEBUGFUNCMSGOUT;
     return &errortext[0];
   }
 }
@@ -860,6 +906,8 @@ char *get_lasterror(void) {
 void show_error(int32 number, char *text) {
   byte *badline;
   errortype severity;
+
+  DEBUGFUNCMSGIN;
   basicvars.error_number = number;
   severity = number==0 ? FATAL : NONFATAL;
   strcpy(errortext, text);
@@ -867,35 +915,40 @@ void show_error(int32 number, char *text) {
   if (badline==NIL)     /* 'ERROR' was not used in program - Assume it was in the command line */
     basicvars.error_line = 0;
   else {        /* ERROR used in running program */
-    basicvars.error_line = get_lineno(badline);
+    basicvars.error_line = GET_LINENO(badline);
   }
   handle_error(severity);
+  DEBUGFUNCMSGOUT;
 }
 
 /*
 ** 'set_error' is called to set up a normal Basic error handler
 */
 void set_error(void) {
+  DEBUGFUNCMSGIN;
   basicvars.error_handler.current = basicvars.current;
-  basicvars.error_handler.stacktop = get_safestack();
+  basicvars.error_handler.stacktop = basicvars.safestack.bytesp; /* get_safestack */
   basicvars.error_handler.islocal = FALSE;
 #ifdef DEBUG
   if (basicvars.debug_flags.debug) fprintf(stderr, "Set up ON ERROR handler at %p,  stack = %p\n",
    basicvars.error_handler.current, basicvars.error_handler.stacktop);
 #endif
+  DEBUGFUNCMSGOUT;
 }
 
 /*
 ** 'set_local_error' is called to set up a 'local' Basic error handler
 */
 void set_local_error(void) {
+  DEBUGFUNCMSGIN;
   basicvars.error_handler.current = basicvars.current;
-  basicvars.error_handler.stacktop = get_stacktop();
+  basicvars.error_handler.stacktop = basicvars.stacktop.bytesp; /* get_stacktop */
   basicvars.error_handler.islocal = TRUE;
 #ifdef DEBUG
   if (basicvars.debug_flags.debug) fprintf(stderr, "Set up ON ERROR LOCAL handler at %p,  stack = %p\n",
    basicvars.error_handler.current, basicvars.error_handler.stacktop);
 #endif
+  DEBUGFUNCMSGOUT;
 }
 
 /*
@@ -903,10 +956,12 @@ void set_local_error(void) {
 ** Basic program
 */
 void clear_error(void) {
+  DEBUGFUNCMSGIN;
   basicvars.error_handler.current = NIL;
   basicvars.local_restart = NIL;
   basicvars.escape = FALSE;
 #ifdef DEBUG
   if (basicvars.debug_flags.debug) fprintf(stderr, "Clearing ON ERROR handler\n");
 #endif
+  DEBUGFUNCMSGOUT;
 }
