@@ -19,7 +19,7 @@
 ** Boston, MA 02111-1307, USA.
 **
 **
-**	This file contains the file I/O routines for the interpreter
+**      This file contains the file I/O routines for the interpreter
 */
 
 /*
@@ -30,6 +30,8 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
+#include <unistd.h>
+#include <sys/types.h>
 #include "common.h"
 #include "miscprocs.h"
 #include "target.h"
@@ -51,23 +53,35 @@ typedef enum {CLOSED, OPENIN, OPENUP, OPENOUT, NETWORK} filestate;
 typedef enum {OKAY, PENDING, ATEOF} eofstate;
 
 typedef struct {
-  FILE *stream;			/* 'C' file handle for the file */
-  filestate filetype;		/* Way in which file has been opened */
-  eofstate eofstatus;		/* Current end-of-file status */
-  boolean lastwaswrite;		/* TRUE if the last operation on a file was a write */
-  int nethandle;		/* network handle */
+  FILE *stream;                 /* 'C' file handle for the file */
+  filestate filetype;           /* Way in which file has been opened */
+  eofstate eofstatus;           /* Current end-of-file status */
+  boolean lastwaswrite;         /* TRUE if the last operation on a file was a write */
+  int nethandle;                /* network handle */
 } fileblock;
 
 #ifdef TARGET_RISCOS
-#define MAXFILES 4		/* Maximum number of files that can be open simultaneously - only tracks networking on RISC OS */
-#define FIRSTHANDLE 4		/* Number of first handle */
+#define MAXFILES 4              /* Maximum number of files that can be open simultaneously - only tracks networking on RISC OS */
+#define FIRSTHANDLE 4           /* Number of first handle */
 #else
-#define MAXFILES 25		/* Maximum number of files that can be open simultaneously */
-#define FIRSTHANDLE 254		/* Number of first handle */
+#define MAXFILES 256            /* Maximum number of files that can be open simultaneously */
+#define FIRSTHANDLE 254         /* Number of first handle */
 #endif
 
 static fileblock fileinfo [MAXFILES+1];
 
+/*
+** 'isapath' returns TRUE if the file name passed to it is a pathname, that
+** is, contains directories as well as a file name, and FALSE if it consists
+** of just the name of the file. 'DIRSEPS' is a string containing all the
+** characters that can be used in a file name to separate directories or
+** the name of the file from the directories.
+** This code is meant to be operating system independent
+*/
+boolean isapath(char *name) {
+  return strpbrk(name, DIR_SEPS)!=NIL;
+}
+
 #ifdef TARGET_RISCOS
 
 /* ================================================================= */
@@ -95,10 +109,6 @@ static fileblock fileinfo [MAXFILES+1];
 #define OPEN_OUTPUT 0x80
 #define OPEN_UPDATE 0xC0
 
-boolean isapath(char *name) {
-  return strpbrk(name, DIR_SEPS)!=NIL;
-}
-
 /*
 ** 'report' is called when one of the _kernel_xxx functions
 ** returns -2 (indicating that the corresponding SWI call
@@ -117,7 +127,7 @@ static void report(void) {
 static int32 fileio_read(int32 handle) {
   int32 value;
   value = _kernel_osbget(handle);
-  if (value==_kernel_ERROR) report();	/* Function returned -2 = SWI call failed */
+  if (value==_kernel_ERROR) report();   /* Function returned -2 = SWI call failed */
   if (value==-1) error(ERR_CANTREAD);
   return value;
 }
@@ -128,15 +138,15 @@ static int32 fileio_read(int32 handle) {
 int32 fileio_openin(char *name, int32 namelen) {
   int32 handle;
   char filename [FNAMESIZE];
-  char *tfilename;
+
   memmove(filename, name, namelen);
-  filename[namelen] = NUL;		/* Get a null-terminated version of the file name */
+  filename[namelen] = NUL;              /* Get a null-terminated version of the file name */
   handle = _kernel_osfind(OPEN_INPUT, filename);
   if (handle==_kernel_ERROR) {
     if (matrixflags.translatefname == 0) {
       report();
     } else {
-      tfilename=translatefname(filename);
+      char *tfilename = translatefname(filename);
       handle = _kernel_osfind(OPEN_INPUT, tfilename);
       if (handle==_kernel_ERROR) {
         report();
@@ -155,11 +165,11 @@ int32 fileio_openin(char *name, int32 namelen) {
 int32 fileio_openout(char *name, int32 namelen) {
   int32 handle;
   char filename [FNAMESIZE];
-  char *tfilename;
+
   memmove(filename, name, namelen);
   filename[namelen] = NUL;
   if(matrixflags.translatefname == 1) {
-    tfilename=translatefname(filename);
+    char *tfilename = translatefname(filename);
     handle = _kernel_osfind(OPEN_OUTPUT, tfilename);
   } else {
     handle = _kernel_osfind(OPEN_OUTPUT, filename);
@@ -183,8 +193,8 @@ int32 fileio_openup(char *name, int32 namelen) {
 #ifndef NONET
   /* Check, does it start "ip4:" if so use network handler to open it. */
   if (strncmp(filename, "ip0:", 4)==0 || strncmp(filename, "ip4:", 4)==0 || strncmp(filename, "ip6:", 4)==0) {
-    for (n=FIRSTHANDLE; n>0 && fileinfo[n].stream!=NIL; n--);	/* Find an unused handle */
-    handle=brandynet_connect(filename+4, filename[2]);
+    for (n=FIRSTHANDLE; n>0 && fileinfo[n].stream!=NIL; n--);   /* Find an unused handle */
+    handle=brandynet_connect(filename+4, filename[2], 1);
     if (handle == -1) return 0;
     fileinfo[n].stream = (void *)42; /* Not used, but != NIL */
     fileinfo[n].filetype = NETWORK;
@@ -241,14 +251,14 @@ static void close_file(int32 handle) {
 }
 
 void fileio_close(int32 handle) {
-  int32 n;
-  if (handle==0) {	/* Close all open files */
+  if (handle==0) {      /* Close all open files */
+    int32 n;
     for (n=FIRSTHANDLE; n>0; n--) {
       if (fileinfo[n].filetype!=CLOSED) close_file(n);
     }
     close_file(handle);
   }
-  else {	/* close one file */
+  else {        /* close one file */
     close_file(handle);
   }
 }
@@ -258,7 +268,10 @@ void fileio_close(int32 handle) {
 */
 int32 fileio_bget(int32 handle) {
   int32 ch = 0;
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return 0;
+  }
 
 #ifndef NONET
   if ((handle <= FIRSTHANDLE) && (fileinfo[handle].filetype == NETWORK)) {
@@ -267,6 +280,7 @@ int32 fileio_bget(int32 handle) {
       if (fileinfo[handle].eofstatus == PENDING) {
         fileinfo[handle].eofstatus = ATEOF;
         error(ERR_HITEOF);
+        return 0;
       } else {
         fileinfo[handle].eofstatus = PENDING;
       }
@@ -278,7 +292,10 @@ int32 fileio_bget(int32 handle) {
     regs.r[0] = 0;
     regs.r[1] = handle;
     oserror = _kernel_swi(OS_BGet, &regs, &regs);
-    if (oserror!=NIL) error(ERR_CMDFAIL, oserror->errmess);
+    if (oserror!=NIL) {
+      error(ERR_CMDFAIL, oserror->errmess);
+      return 0;
+    }
     ch=regs.r[0];
 #ifndef NONET
   }
@@ -294,12 +311,11 @@ int32 fileio_bget(int32 handle) {
 ** buffer is large enough to hold MAXSTRING (65536) characters.
 */
 int32 fileio_getdol(int32 handle, char *buffer) {
-  int32 ch, length;
-  length = 0;
+  int32 length = 0;
   do {
-    ch = fileio_bget(handle);
-    if (ch==_kernel_ERROR) report();	/* Function returned -2 = SWI call failed */
-    if (ch==-1 || ch==LF) break;	/* At end of file or reached end of line */
+    int32 ch = fileio_bget(handle);
+    if (ch==_kernel_ERROR) report();    /* Function returned -2 = SWI call failed */
+    if (ch==-1 || ch==LF) break;        /* At end of file or reached end of line */
     buffer[length] = ch;
     length++;
   } while (TRUE);
@@ -348,7 +364,7 @@ void fileio_getnumber(int32 handle, boolean *isint, int64 *ip, float64 *fp) {
     memmove(fp, temp, sizeof(float64));
     *isint = FALSE;
     break;
-  case PRINT_FLOAT5: {		/* Acorn 5-byte floating point format */
+  case PRINT_FLOAT5: {          /* Acorn 5-byte floating point format */
 /*
 ** Acorn's five byte format consists of a four byte mantissa and
 ** a one byte exponent. The mantissa, x, is in little endian format
@@ -392,17 +408,18 @@ int32 fileio_getstring(int32 handle, char *p) {
   int32 marker = 0, length = 0, n = 0;
   marker = fileio_read(handle);
   switch (marker) {
-  case PRINT_SHORTSTR:	/* Reading short string in 'Acorn' format */
+  case PRINT_SHORTSTR:  /* Reading short string in 'Acorn' format */
     length = fileio_read(handle);
     for (n=1; n<=length; n++) p[length-n] = fileio_read(handle);
     break;
-  case PRINT_LONGSTR:	/* Reading long string */
-    length = 0;		/* Start by reading the string length (four bytes, little endian) */
+  case PRINT_LONGSTR:   /* Reading long string */
+    length = 0;         /* Start by reading the string length (four bytes, little endian) */
     for (n=0; n<sizeof(int32); n++) length+=fileio_read(handle)<<(n*BYTESHIFT);
     for (n=0; n<length; n++) p[n] = fileio_read(handle);
     break;
   default:
     error(ERR_TYPESTR);
+    return 0;
   }
   return length;
 }
@@ -411,7 +428,10 @@ int32 fileio_getstring(int32 handle, char *p) {
 ** 'fileio_bput' writes a character to a file
 */
 void fileio_bput(int32 handle, int32 value) {
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
 #ifndef NONET
   if ((handle <= FIRSTHANDLE) && (fileinfo[handle].filetype==NETWORK)) {
     if(net_bput(fileinfo[handle].nethandle, value)) error(ERR_CANTWRITE);
@@ -432,7 +452,10 @@ void fileio_bput(int32 handle, int32 value) {
 ** 'fileio_bputstr' writes a string to a file
 */
 void fileio_bputstr(int32 handle, char *string, int32 length) {
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
 #ifndef NONET
   if ((handle <= FIRSTHANDLE) && (fileinfo[handle].filetype==NETWORK)) {
     if(net_bputstr(fileinfo[handle].nethandle, string, length)) error(ERR_CANTWRITE);
@@ -440,13 +463,16 @@ void fileio_bputstr(int32 handle, char *string, int32 length) {
 #endif
     _kernel_oserror *oserror;
     _kernel_swi_regs regs;
-    regs.r[0] = 2;	/* OS_GBPB 2 = write to file at current file pointer position */
+    regs.r[0] = 2;      /* OS_GBPB 2 = write to file at current file pointer position */
     regs.r[1] = handle;
     regs.r[2] = TOINT((int)string);
     regs.r[3] = length;
     oserror = _kernel_swi(OS_GBPB, &regs, &regs);
-    if (oserror!=NIL) error(ERR_CMDFAIL, oserror->errmess);
-    if (regs.r[3]!=0) error(ERR_CANTWRITE);	/* Not all the data was written to the file */
+    if (oserror!=NIL) {
+      error(ERR_CMDFAIL, oserror->errmess);
+      return;
+    }
+    if (regs.r[3]!=0) error(ERR_CANTWRITE);     /* Not all the data was written to the file */
 #ifndef NONET
   }
 #endif
@@ -499,16 +525,16 @@ void fileio_printfloat(int32 handle, float64 value) {
 ** four bytes. The string is written in 'true' order
 */
 void fileio_printstring(int32 handle, char *string, int32 length) {
-  int32 n, temp;
-  if (length<SHORT_STRING) {	/* Write string in Acorn format */
+  int32 n;
+  if (length<SHORT_STRING) {    /* Write string in Acorn format */
     fileio_bput(handle, PRINT_SHORTSTR);
     fileio_bput(handle, length);
     if (length>0) for (n=length-1; n>=0; n--) fileio_bput(handle, string[n]);
   }
-  else {	/* Long string - Use interpreter's extended format */
+  else {        /* Long string - Use interpreter's extended format */
+    int32 temp = length;
     fileio_bput(handle, PRINT_LONGSTR);
-    temp = length;
-    for (n=0; n<sizeof(int32); n++) {	/* Write four byte length to file */
+    for (n=0; n<sizeof(int32); n++) {   /* Write four byte length to file */
       fileio_bput(handle, temp & BYTEMASK);
       temp = temp>>BYTESHIFT;
     }
@@ -520,10 +546,10 @@ void fileio_printstring(int32 handle, char *string, int32 length) {
 ** 'fileio_getptr' returns the current value of the file pointer for
 ** the file 'handle'
 */
-int32 fileio_getptr(int32 handle) {
+int64 fileio_getptr(int32 handle) {
   int32 pointer;
   if (handle == 0) return 0;
-  pointer = _kernel_osargs(0, handle, 0);	/* OS_Args 0 = read file pointer */
+  pointer = _kernel_osargs(0, handle, 0);       /* OS_Args 0 = read file pointer */
   if (pointer==_kernel_ERROR) report();
   return pointer;
 }
@@ -532,18 +558,18 @@ int32 fileio_getptr(int32 handle) {
 ** 'fileio_setptr' is used to set the current file pointer of
 ** the file 'handle'
 */
-void fileio_setptr(int32 handle, int32 newoffset) {
+void fileio_setptr(int32 handle, int64 newoffset) {
   int32 result;
-  result = _kernel_osargs(1, handle, newoffset);	/* OS_Args 1 = set file pointer */
+  result = _kernel_osargs(1, handle, newoffset);        /* OS_Args 1 = set file pointer */
   if (result==_kernel_ERROR) report();
 }
 
 /*
 ** 'fileio_getext' returns the size of the file with handle 'handle'
 */
-int32 fileio_getext(int32 handle) {
+int64 fileio_getext(int32 handle) {
   int32 extent;
-  extent = _kernel_osargs(2, handle, 0);	/* OS_Args 2 = read file's extent (size) */
+  extent = _kernel_osargs(2, handle, 0);        /* OS_Args 2 = read file's extent (size) */
   if (extent==_kernel_ERROR) report();
   return extent;
 }
@@ -552,9 +578,9 @@ int32 fileio_getext(int32 handle) {
 ** 'fileio_setext' is called to alter the extent (size) of the file
 ** with handle 'handle'
 */
-void fileio_setext(int32 handle, int32 newsize) {
+void fileio_setext(int32 handle, int64 newsize) {
   int32 result;
-  result = _kernel_osargs(3, handle, newsize);	/* OS_Args 3 = alter file's extent (size) */
+  result = _kernel_osargs(3, handle, newsize);  /* OS_Args 3 = alter file's extent (size) */
   if (result==_kernel_ERROR) report();
 }
 
@@ -564,7 +590,7 @@ void fileio_setext(int32 handle, int32 newsize) {
 */
 int32 fileio_eof(int32 handle) {
   int32 result;
-  result = _kernel_osargs(5, handle, 0);	/* OS_Args 5 = Check end-of-file status */
+  result = _kernel_osargs(5, handle, 0);        /* OS_Args 5 = Check end-of-file status */
   if (result==_kernel_ERROR) report();
   return result==0 ? FALSE : TRUE;
 }
@@ -586,7 +612,7 @@ void init_fileio(void) {
 #else /* !TARGET_RISCOS */
 
 /* ================================================================== */
-/* ============= NetBSD/Linux/DOS versions of functions ============= */
+/* ========= NetBSD/Linux/DOS/Windows versions of functions ========= */
 /* ================================================================== */
 
 /*
@@ -609,18 +635,6 @@ void init_fileio(void) {
 #define UPMODE "r+"
 #endif
 
-/*
-** 'isapath' returns TRUE if the file name passed to it is a pathname, that
-** is, contains directories as well as a file name, and FALSE if it consists
-** of just the name of the file. 'DIRSEPS' is a string containing all the
-** characters that can be used in a file name to separate directories or
-** the name of the file from the directories.
-** This code is meant to be operating system independent
-*/
-boolean isapath(char *name) {
-  return strpbrk(name, DIR_SEPS)!=NIL;
-}
-
 /*
 ** 'map_handle' maps a Basic-style file handle to the corresponding entry
 ** in the 'fileinfo' table and checks that the handle is valid
@@ -638,15 +652,21 @@ int32 fileio_openin(char *name, int32 namelen) {
   FILE *thefile;
   int32 n;
   char filename [FNAMESIZE];
-  char filenameb[FNAMESIZE];
-  char *tfilename;
-  if ((namelen < 0) || (namelen > (FNAMESIZE - 1))) error(ERR_INVALIDFNAME);
-  for (n=0; n<MAXFILES && fileinfo[n].stream!=NIL; n++);	/* Find an unused handle */
-  if (n>=MAXFILES) error(ERR_MAXHANDLE);
+
+  if ((namelen < 0) || (namelen > (FNAMESIZE - 1))) {
+    error(ERR_INVALIDFNAME);
+    return 0;
+  }
+  for (n=0; n<MAXFILES && fileinfo[n].stream!=NIL; n++);        /* Find an unused handle */
+  if (n>=MAXFILES) {
+    error(ERR_MAXHANDLE);
+    return 0;
+  }
   memmove(filename, name, namelen);
   filename[namelen] = asc_NUL;
   thefile = fopen(filename, INMODE);
   if (thefile==NIL) {
+    char filenameb[FNAMESIZE];
     strncpy(filenameb, filename, FNAMESIZE);
     strcat(filenameb, ".bbc"); /* Append a .bbc suffix and try again */
     thefile = fopen(filenameb, INMODE);
@@ -654,7 +674,7 @@ int32 fileio_openin(char *name, int32 namelen) {
       if (matrixflags.translatefname == 0) {
         return 0;
       } else {
-        tfilename=translatefname(filename);
+        char *tfilename = translatefname(filename);
         thefile = fopen(tfilename, INMODE);
         if (thefile==NIL) {
           return 0; /* Could not open file - Return null handle */
@@ -683,19 +703,28 @@ int32 fileio_openout(char *name, int32 namelen) {
   FILE *thefile;
   int32 n;
   char filename [FNAMESIZE];
-  char *tfilename;
-  if ((namelen < 0) || (namelen > (FNAMESIZE - 1))) error(ERR_INVALIDFNAME);
-  for (n=0; n<MAXFILES && fileinfo[n].stream!=NIL; n++);	/* Find an unused handle */
-  if (n>=MAXFILES) error(ERR_MAXHANDLE);
+
+  if ((namelen < 0) || (namelen > (FNAMESIZE - 1))) {
+    error(ERR_INVALIDFNAME);
+    return 0;
+  }
+  for (n=0; n<MAXFILES && fileinfo[n].stream!=NIL; n++);        /* Find an unused handle */
+  if (n>=MAXFILES) {
+    error(ERR_MAXHANDLE);
+    return 0;
+  }
   memmove(filename, name, namelen);
   filename[namelen] = asc_NUL;
   if(matrixflags.translatefname == 1) {
-    tfilename=translatefname(filename);
+    char *tfilename = translatefname(filename);
     thefile = fopen(tfilename, OUTMODE);
   } else {
     thefile = fopen(filename, OUTMODE);
   }
-  if (thefile==NIL) error(ERR_OPENWRITE, filename);
+  if (thefile==NIL) {
+    error(ERR_OPENWRITE, filename);
+    return 0;
+  }
   fileinfo[n].stream = thefile;
   fileinfo[n].filetype = OPENOUT;
   fileinfo[n].eofstatus = OKAY;
@@ -714,16 +743,22 @@ int32 fileio_openup(char *name, int32 namelen) {
   char filenameb[FNAMESIZE];
   char *tfilename;
 
-  if ((namelen < 0) || (namelen > (FNAMESIZE - 1))) error(ERR_INVALIDFNAME);
-  for (n=0; n<MAXFILES && fileinfo[n].stream!=NIL; n++);	/* Find an unused handle */
-  if (n>=MAXFILES) error(ERR_MAXHANDLE);
+  if ((namelen < 0) || (namelen > (FNAMESIZE - 1))) {
+    error(ERR_INVALIDFNAME);
+    return 0;
+  }
+  for (n=0; n<MAXFILES && fileinfo[n].stream!=NIL; n++);        /* Find an unused handle */
+  if (n>=MAXFILES) {
+    error(ERR_MAXHANDLE);
+    return 0;
+  }
   memmove(filename, name, namelen);
   filename[namelen] = asc_NUL;
 #ifndef NONET
   /* Check, does it start "ip4:" if so use network handler to open it. */
   if (!strncmp(filename, "ip0:", 4) || !strncmp(filename, "ip4:", 4) || !strncmp(filename, "ip6:", 4)) {
     int handle;
-    handle=brandynet_connect(filename+4, filename[2]);
+    handle=brandynet_connect(filename+4, filename[2], 1);
     if (handle == -1) return 0;
     fileinfo[n].stream = (void *)42; /* Not used, but != NIL */
     fileinfo[n].filetype = NETWORK;
@@ -791,12 +826,12 @@ static void close_file(int32 handle) {
 */
 void fileio_close(int32 handle) {
   int32 n;
-  if (handle==0) {	/* Close all open files */
+  if (handle==0) {      /* Close all open files */
     for (n=0; n<MAXFILES; n++) {
       if (fileinfo[n].filetype!=CLOSED) close_file(n);
     }
   }
-  else {	/* close one file */
+  else {        /* close one file */
     n = map_handle(handle);
     if (fileinfo[n].filetype!=CLOSED) close_file(n);
   }
@@ -811,36 +846,40 @@ void fileio_close(int32 handle) {
 int32 fileio_bget(int32 handle) {
   int32 ch;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return 0;
+  }
   handle = map_handle(handle);
 #ifndef NONET
   if (fileinfo[handle].filetype == NETWORK) {
     ch=net_bget(fileinfo[handle].nethandle);
     if (ch == -2) {
       if (fileinfo[handle].eofstatus == PENDING) {
-	fileinfo[handle].eofstatus = ATEOF;
-	error(ERR_HITEOF);
+        fileinfo[handle].eofstatus = ATEOF;
+        error(ERR_HITEOF);
+        return 0;
       } else {
-	fileinfo[handle].eofstatus = PENDING;
+        fileinfo[handle].eofstatus = PENDING;
       }
     }
   } else {
 #endif
-    if (fileinfo[handle].eofstatus!=OKAY) {	/* If EOF is pending, flag an error */
+    if (fileinfo[handle].eofstatus!=OKAY) {     /* If EOF is pending, flag an error */
       fileinfo[handle].eofstatus = ATEOF;
       error(ERR_HITEOF);
+      return 0;
     }
-    else if (fileinfo[handle].filetype==OPENOUT) {	/* If file is open for output, read one char */
-      ch = asc_NUL;
+    else if (fileinfo[handle].filetype==OPENOUT) {      /* If file is open for output, read one char */
       fileinfo[handle].eofstatus = PENDING;
     }
-    if (fileinfo[handle].lastwaswrite) {		/* Ensure everything has been written to disk first */
+    if (fileinfo[handle].lastwaswrite) {                /* Ensure everything has been written to disk first */
       fflush(fileinfo[handle].stream);
       fileinfo[handle].lastwaswrite = FALSE;
     }
-    ch = fgetc(fileinfo[handle].stream);	/* Read a character */
+    ch = fgetc(fileinfo[handle].stream);        /* Read a character */
     if (ch==EOF) {
-      fileinfo[handle].eofstatus = PENDING;	/* If call returns 'EOF' set 'PENDING EOF' flag */
+      fileinfo[handle].eofstatus = PENDING;     /* If call returns 'EOF' set 'PENDING EOF' flag */
       ch = 0;
     }
     fileinfo[handle].lastwaswrite = FALSE;
@@ -863,23 +902,30 @@ int32 fileio_getdol(int32 handle, char *buffer) {
   char *p;
   int32 length;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return 0;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].eofstatus!=OKAY) {	/* If EOF is pending or EOF, flag an error */
+  if (fileinfo[handle].eofstatus!=OKAY) {       /* If EOF is pending or EOF, flag an error */
     fileinfo[handle].eofstatus = ATEOF;
     error(ERR_HITEOF);
+    return 0;
   }
-  if (fileinfo[handle].lastwaswrite) {		/* Ensure everything has been written to disk first */
+  if (fileinfo[handle].lastwaswrite) {          /* Ensure everything has been written to disk first */
     fflush(fileinfo[handle].stream);
     fileinfo[handle].lastwaswrite = FALSE;
   }
   p = fgets(buffer, MAXSTRING, fileinfo[handle].stream);
-  if (p==NIL) error(ERR_CANTREAD);	/* Read failed utterly */
+  if (p==NIL) {
+    error(ERR_CANTREAD);      /* Read failed utterly */
+    return 0;
+  }
   length = strlen(buffer);
-  p = buffer+length-1;	/* Point at line end character */
-  if (*p==asc_LF) {	/* Got a 'linefeed' at the end of the line */
+  p = buffer+length-1;  /* Point at line end character */
+  if (*p==asc_LF) {     /* Got a 'linefeed' at the end of the line */
     length--;
-    if (length>0 && *(p-1)==asc_CR) length--;	/* Got a 'carriage return-linefeed' pair */
+    if (length>0 && *(p-1)==asc_CR) length--;   /* Got a 'carriage return-linefeed' pair */
   }
   return length;
 }
@@ -912,13 +958,17 @@ void fileio_getnumber(int32 handle, boolean *isint, int64 *ip, float64 *fp) {
   char temp[sizeof(float64)];
 
   memset(temp,0,sizeof(float64));
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].eofstatus!=OKAY) {	/* If EOF is pending, flag an error */
+  if (fileinfo[handle].eofstatus!=OKAY) {       /* If EOF is pending, flag an error */
     fileinfo[handle].eofstatus = ATEOF;
     error(ERR_HITEOF);
+    return;
   }
-  if (fileinfo[handle].lastwaswrite) {	/* Ensure everything has been written to disk first */
+  if (fileinfo[handle].lastwaswrite) {  /* Ensure everything has been written to disk first */
     fflush(fileinfo[handle].stream);
     fileinfo[handle].lastwaswrite = FALSE;
   }
@@ -991,25 +1041,29 @@ int32 fileio_getstring(int32 handle, char *p) {
   FILE *stream;
   int32 marker, length = 0, n;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return 0;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].eofstatus!=OKAY) {	/* If EOF is pending, flag an error */
+  if (fileinfo[handle].eofstatus!=OKAY) {       /* If EOF is pending, flag an error */
     fileinfo[handle].eofstatus = ATEOF;
     error(ERR_HITEOF);
+    return 0;
   }
-  if (fileinfo[handle].lastwaswrite) {		/* Ensure everything has been written to disk first */
+  if (fileinfo[handle].lastwaswrite) {          /* Ensure everything has been written to disk first */
     fflush(fileinfo[handle].stream);
     fileinfo[handle].lastwaswrite = FALSE;
   }
   stream = fileinfo[handle].stream;
   marker = fileio_read(stream);
   switch (marker) {
-  case PRINT_SHORTSTR:	/* Reading short string in 'Acorn' format */
+  case PRINT_SHORTSTR:  /* Reading short string in 'Acorn' format */
     length = fileio_read(stream);
     for (n=1; n<=length; n++) p[length-n] = fileio_read(stream);
     break;
-  case PRINT_LONGSTR:	/* Reading long string */
-    length = 0;		/* Start by reading the string length (four bytes, little endian) */
+  case PRINT_LONGSTR:   /* Reading long string */
+    length = 0;         /* Start by reading the string length (four bytes, little endian) */
     for (n=0; n<sizeof(int32); n++) length+=fileio_read(stream)<<(n*BYTESHIFT);
     for (n=0; n<length; n++) p[n] = fileio_read(stream);
     break;
@@ -1031,17 +1085,26 @@ static void fileio_write(FILE *stream, int32 value) {
 void fileio_bput(int32 handle, int32 value) {
   int32 result;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
 #ifndef NONET
   if (fileinfo[handle].filetype==NETWORK) {
     if(net_bput(fileinfo[handle].nethandle, value)) error(ERR_CANTWRITE);
   } else {
 #endif
-    if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+    if (fileinfo[handle].filetype==OPENIN) {
+      error(ERR_OPENIN);
+      return;
+    }
     fileinfo[handle].eofstatus = OKAY;
     result = fputc(value, fileinfo[handle].stream);
-    if (result==EOF) error(ERR_CANTWRITE);
+    if (result==EOF) {
+      error(ERR_CANTWRITE);
+      return;
+    }
     fileinfo[handle].lastwaswrite = TRUE;
 #ifndef NONET
   }
@@ -1054,17 +1117,26 @@ void fileio_bput(int32 handle, int32 value) {
 void fileio_bputstr(int32 handle, char *string, int32 length) {
   int32 result;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
 #ifndef NONET
   if (fileinfo[handle].filetype==NETWORK) {
     if(net_bputstr(fileinfo[handle].nethandle, string, length)) error(ERR_CANTWRITE);
   } else {
 #endif
-    if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+    if (fileinfo[handle].filetype==OPENIN) {
+      error(ERR_OPENIN);
+      return;
+    }
     fileinfo[handle].eofstatus = OKAY;
     result = fwrite(string, sizeof(char), length, fileinfo[handle].stream);
-    if (result!=length) error(ERR_CANTWRITE);
+    if (result!=length) {
+      error(ERR_CANTWRITE);
+      return;
+    }
     fileinfo[handle].lastwaswrite = TRUE;
 #ifndef NONET
   }
@@ -1081,9 +1153,15 @@ void fileio_printint(int32 handle, int32 value) {
   FILE *stream;
   int32 n;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+  if (fileinfo[handle].filetype==OPENIN) {
+    error(ERR_OPENIN);
+    return;
+  }
   fileinfo[handle].eofstatus = OKAY;
   stream = fileinfo[handle].stream;
   fileio_write(stream, PRINT_INT);
@@ -1094,9 +1172,15 @@ void fileio_printint(int32 handle, int32 value) {
 void fileio_printuint8(int32 handle, uint8 value) {
   FILE *stream;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+  if (fileinfo[handle].filetype==OPENIN) {
+    error(ERR_OPENIN);
+    return;
+  }
   fileinfo[handle].eofstatus = OKAY;
   stream = fileinfo[handle].stream;
   fileio_write(stream, PRINT_UINT8);
@@ -1108,9 +1192,15 @@ void fileio_printint64(int32 handle, int64 value) {
   FILE *stream;
   int32 n;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+  if (fileinfo[handle].filetype==OPENIN) {
+    error(ERR_OPENIN);
+    return;
+  }
   fileinfo[handle].eofstatus = OKAY;
   stream = fileinfo[handle].stream;
   fileio_write(stream, PRINT_INT64);
@@ -1131,9 +1221,15 @@ void fileio_printfloat(int32 handle, float64 value) {
   int32 n;
   char temp[sizeof(float64)];
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+  if (fileinfo[handle].filetype==OPENIN) {
+    error(ERR_OPENIN);
+    return;
+  }
   fileinfo[handle].eofstatus = OKAY;
   stream = fileinfo[handle].stream;
   fileio_write(stream, PRINT_FLOAT);
@@ -1165,27 +1261,37 @@ void fileio_printfloat(int32 handle, float64 value) {
 */
 void fileio_printstring(int32 handle, char *string, int32 length) {
   FILE *stream;
-  int32 n, temp, result;
+  int32 n;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
-  if (fileinfo[handle].filetype==OPENIN) error(ERR_OPENIN);
+  if (fileinfo[handle].filetype==OPENIN) {
+    error(ERR_OPENIN);
+    return;
+  }
   fileinfo[handle].eofstatus = OKAY;
   stream = fileinfo[handle].stream;
-  if (length<SHORT_STRING) {	/* Write string in Acorn format */
+  if (length<SHORT_STRING) {    /* Write string in Acorn format */
     fileio_write(stream, PRINT_SHORTSTR);
     fileio_write(stream, length);
     if (length>0) for (n=length-1; n>=0; n--) fileio_write(stream, string[n]);
   }
-  else {	/* Long string - Use interpreter's extended format */
+  else {        /* Long string - Use interpreter's extended format */
+    int32 result;
+    int32 temp = length;
     fileio_write(stream, PRINT_LONGSTR);
-    temp = length;
-    for (n=0; n<sizeof(int32); n++) {	/* Write four byte length to file */
+    for (n=0; n<sizeof(int32); n++) {   /* Write four byte length to file */
       fileio_write(stream, temp & BYTEMASK);
       temp = temp>>BYTESHIFT;
     }
     result = fwrite(string, sizeof(char), length, stream);
-    if (result!=length) error(ERR_CANTWRITE);
+    if (result!=length) {
+      error(ERR_CANTWRITE);
+      return;
+    }
   }
   fileinfo[handle].lastwaswrite = TRUE;
 }
@@ -1193,54 +1299,75 @@ void fileio_printstring(int32 handle, char *string, int32 length) {
 /*
 ** 'fileio_setptr' is used to set the current file pointer
 */
-void fileio_setptr(int32 handle, int32 newoffset) {
+void fileio_setptr(int32 handle, int64 newoffset) {
   int32 result;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return;
+  }
   handle = map_handle(handle);
   result = fseek(fileinfo[handle].stream, newoffset, SEEK_SET);
-  if (result==-1) error(ERR_SETPTRFAIL);	/* File pointer cannot be set */
+  if (result==-1) {                             /* File pointer cannot be set */
+    error(ERR_SETPTRFAIL);
+    return;
+  }
   fileinfo[handle].eofstatus = OKAY;
 }
 
 /*
 ** 'fileio_getptr' returns the current value of the file pointer
 */
-int32 fileio_getptr(int32 handle) {
-  int32 result;
+int64 fileio_getptr(int32 handle) {
+  int64 result;
 
   if (handle==0) return 0; /* This is what happens on RISC OS 3.71 */
   handle = map_handle(handle);
-  result = TOINT(ftell(fileinfo[handle].stream));
-  if (result==-1) error(ERR_GETPTRFAIL);	/* File pointer cannot be read */
+  result = ftell(fileinfo[handle].stream);
+  if (result==-1) error(ERR_GETPTRFAIL);        /* File pointer cannot be read */
   return result;
 }
 
 /*
 ** 'fileio_getext' returns the size of a file
 */
-int32 fileio_getext(int32 handle) {
-  long int position, length;
+int64 fileio_getext(int32 handle) {
+  int64 position, length;
   FILE *stream;
 
-  if (handle==0) error(ERR_BADHANDLE);
+  if (handle==0) {
+    error(ERR_BADHANDLE);
+    return 0;
+  }
   handle = map_handle(handle);
   stream = fileinfo[handle].stream;
   position = ftell(stream);
-  if (position==-1) error(ERR_GETEXTFAIL);	/* Cannot find size of file */
-  fseek(stream, 0, SEEK_END);			/* Find the end of the file */
+  if (position==-1) {
+    error(ERR_GETEXTFAIL);      /* Cannot find size of file */
+    return 0;
+  }
+  fseek(stream, 0, SEEK_END);                   /* Find the end of the file */
   length = ftell(stream);
-  fseek(stream, position, SEEK_SET);	/* Restore file to its original file pointer position */
-  return TOINT(length);
+  fseek(stream, position, SEEK_SET);    /* Restore file to its original file pointer position */
+  return length;
 }
 
 /*
-** 'fileio_setext' allows the size of a file to be changed. This
-** is not supported except under RISC OS
+** 'fileio_setext' allows the size of a file to be changed.
 */
-void fileio_setext(int32 handle, int32 newsize) {
-  handle = map_handle(handle);
-//error(ERR_UNSUPPORTED);
+void fileio_setext(int32 handle, int64 newsize) {
+  int32 type;
+  
+  handle=map_handle(handle);
+  type=fileinfo[handle].filetype;
+  if((type==OPENOUT) || (type==OPENUP)) {
+    int32 fh = fileno(fileinfo[handle].stream);
+    if (ftruncate(fh, newsize)) {
+      error(ERR_CMDFAIL);
+    }
+  } else {
+    error(ERR_CANTWRITE);
+  }
 }
 
 /*
@@ -1268,7 +1395,7 @@ int32 fileio_eof(int32 handle) {
   stream = fileinfo[handle].stream;
   position = ftell(stream);
   if (position==-1) return feof(stream) ? TRUE : FALSE;
-  fseek(stream, 0, SEEK_END);	/* Find the end of the file */
+  fseek(stream, 0, SEEK_END);   /* Find the end of the file */
   ateof = ftell(stream)==position;
   fseek(stream, position, SEEK_SET);
   return ateof;
@@ -1313,14 +1440,14 @@ static void find_floatformat(void) {
   } value;
   value.temp1 = 1.0;
   if (value.temp2[3]==0x3f)
-    double_type = XMIXED_ENDIAN;	/* ARM old format */
+    double_type = XMIXED_ENDIAN;        /* ARM old format */
   else if (value.temp2[7]==0x3f)
-    double_type = XLITTLE_ENDIAN;	/* X86 */
+    double_type = XLITTLE_ENDIAN;       /* X86 */
   else if (value.temp2[0]==0x3f)
     double_type = XBIG_ENDIAN;
   else if (value.temp2[4]==0x3f)
     double_type = XBIG_MIXED_ENDIAN;
-  else {	/* Unknown format */
+  else {        /* Unknown format */
     double_type = XLITTLE_ENDIAN;
     error(WARN_FUNNYFLOAT);
   }
