@@ -19,7 +19,7 @@
 ** Boston, MA 02111-1307, USA.
 **
 **
-**	This module contains a selection of miscellaneous functions
+**      This module contains a selection of miscellaneous functions
 **
 ** 06-Jan-2019 JGH: secure_tmpnam() tweeked.
 **
@@ -52,6 +52,7 @@ int64 llabs(int64 i) {
 }
 #endif
 
+#if 0 /* Converted to macros in miscprocs.h */
 /*
 ** 'isidstart' returns TRUE if the character passed to it can appear at
 ** the start of an identifier
@@ -75,25 +76,7 @@ boolean isidchar(char ch) {
 boolean isident(byte ch) {
   return isalnum(ch) || ch=='_' || ch=='`';
 }
-
-
-/*
-** 'skip_blanks' skips white space characters. The difference between
-** this and 'skip' is that this one works on 'char' data whilst 'skip'
-** deals with 'byte' data
-*/
-char *skip_blanks(char *p) {
-  while (*p==' ' || *p==asc_TAB) p++;
-  return p;
-}
-
-/*
-** 'skip' is used to skip the 'white space' characters in a tokenised line
-*/
-byte *skip(byte *p) {
-  while (*p==' ' || *p==asc_TAB) p++;
-  return p;
-}
+#endif /* 0 - macro conversion */
 
 /*
 ** 'get_integer' returns the four byte integer found at offset
@@ -114,6 +97,24 @@ int64 get_int64(size_t offset) {
   return ((int64)get_integer(offset) & 0xFFFFFFFFl) + (((int64)(get_integer(offset+4)) & 0xFFFFFFFFl) << 32);
 }
 
+/*
+** 'skip_blanks' skips white space characters. The difference between
+** this and 'skip' is that this one works on 'char' data whilst 'skip'
+** deals with 'byte' data
+*/
+char *skip_blanks(char *p) {
+  while (*p==' ' || *p==asc_TAB) p++;
+  return p;
+}
+
+/*
+** 'skip' is used to skip the 'white space' characters in a tokenised line
+*/
+byte *skip(byte *p) {
+  while (*p==' ' || *p==asc_TAB) p++;
+  return p;
+}
+
 /*
 ** 'get_float' returns the eight byte floating point value found
 ** at offset 'offset' in the Basic workspace. This is used to
@@ -182,7 +183,10 @@ size_t m7offset(size_t p) {
 ** there is a check for overflow.
 */
 void save_current(void) {
-  if (basicvars.curcount==MAXCURCOUNT) error(ERR_OPSTACK);
+  if (basicvars.curcount==MAXCURCOUNT) {
+    error(ERR_OPSTACK);
+    return;
+  }
   basicvars.savedcur[basicvars.curcount] = basicvars.current;
   basicvars.curcount++;
 }
@@ -209,17 +213,17 @@ char *tocstring(char *cp, int32 len) {
   if (len==0) return "";
   if (len>=MAXNAMELEN) len = MAXNAMELEN-1;
   switch (*CAST(cp, byte *)) {
-  case BASIC_TOKEN_PROC:
+  case BASTOKEN_PROC:
     strcpy(cstring, "PROC");
     n = 4;
     cp++;
     break;
-  case BASIC_TOKEN_FN:
+  case BASTOKEN_FN:
     strcpy(cstring, "FN");
     n = 2;
     cp++;
     break;
-  case BASIC_TOKEN_STATICVAR: case BASIC_TOKEN_STATINDVAR:
+  case BASTOKEN_STATICVAR: case BASTOKEN_STATINDVAR:
     cstring[0] = *(cp+1)+'@';
     cstring[1] = '%';
     cstring[2] = asc_NUL;
@@ -232,7 +236,7 @@ char *tocstring(char *cp, int32 len) {
     cp++;
     n++;
   }
-  if (n==MAXNAMELEN) {	/* Put ellipsis at end of name if it has been truncated */
+  if (n==MAXNAMELEN) {  /* Put ellipsis at end of name if it has been truncated */
     cstring[n] = cstring[n+1] = cstring [n+2] = '.';
     n+=3;
   }
@@ -247,9 +251,9 @@ char *tocstring(char *cp, int32 len) {
 */
 library *find_library(byte *wanted) {
   library *lp;
-  lp = basicvars.liblist;	/* Check if it is in a library */
+  lp = basicvars.liblist;       /* Check if it is in a library */
   while (lp!=NIL && (wanted<lp->libstart || wanted>=lp->libstart+lp->libsize)) lp = lp->libflink;
-  if (lp==NIL) {	/* Not found. Check installed libraries */
+  if (lp==NIL) {        /* Not found. Check installed libraries */
     lp = basicvars.installist;
     while (lp!=NIL && (wanted<lp->libstart || wanted>=lp->libstart+lp->libsize)) lp = lp->libflink;
   }
@@ -272,12 +276,12 @@ byte *find_linestart(byte *wanted) {
   byte *p, *last;
   library *lp;
   p = NIL;
-  if (wanted>=basicvars.page && wanted<basicvars.top)	/* Address is in loaded program */
+  if (wanted>=basicvars.page && wanted<basicvars.top)   /* Address is in loaded program */
     p = basicvars.start;
   else {
-    lp = find_library(wanted);	/* Check if it is in a library */
-    if (lp==NIL) return NIL;	/* Could not find where address points */
-    p = lp->libstart;	/* 'wanted' points into a library */
+    lp = find_library(wanted);  /* Check if it is in a library */
+    if (lp==NIL) return NIL;    /* Could not find where address points */
+    p = lp->libstart;   /* 'wanted' points into a library */
   }
   last = p;
   while (p<=wanted) {
@@ -302,22 +306,24 @@ byte *find_linestart(byte *wanted) {
 ** for the line otherwise it searches the program in memory
 */
 byte *find_line(int32 lineno) {
-  byte *p, *cp;
-  library *lp;
-  if (basicvars.runflags.running) {	/* Running program => search program or library */
-    cp = basicvars.current;	/* This is just to reduce the amount of typing */
-    if (cp>=basicvars.page && cp<basicvars.top)		/* Check program for line */
+  byte *p;
+
+  if (basicvars.runflags.running) {     /* Running program => search program or library */
+    byte *cp = basicvars.current;     /* This is just to reduce the amount of typing */
+    if (cp>=basicvars.page && cp<basicvars.top)         /* Check program for line */
       p = basicvars.start;
-    else {	/* Check libraries */
-      lp = find_library(cp);
-      if (lp==NIL) error(ERR_BROKEN, __LINE__, "misc");	/* Could not find line number anywhere */
+    else {      /* Check libraries */
+      library *lp = find_library(cp);
+      if (lp==NIL) {
+        error(ERR_BROKEN, __LINE__, "misc"); /* Could not find line number anywhere */
+        return NULL;
+      }
       p = lp->libstart;
     }
-  }
-  else {	/* Not running a program - Line can only be in the program in memory */
+  } else {        /* Not running a program - Line can only be in the program in memory */
     p = basicvars.start;
   }
-  while (get_lineno(p)<lineno) p+=get_linelen(p);
+  while (GET_LINENO(p)<lineno) p+=GET_LINELEN(p);
   return p;
 }
 
@@ -326,15 +332,15 @@ byte *find_line(int32 lineno) {
 **'low' and 'high' as bytes of data
 */
 void show_byte(size_t low, size_t high) {
-  int32 n, x, ll, count;
+  int32 n, ll, count;
   byte ch;
   //if (low<0 || low>=basicvars.worksize || high<0 || low>high) return;
   if (low>high) return;
   //if (high>basicvars.worksize) high = basicvars.worksize-1;
   count = high-low;
   for (n=0; n<count; n+=16) {
+    int32 x = 0;
     emulate_printf("%06X  ", low);
-    x = 0;
     for (ll=0; ll<16; ll++) {
       if (n+ll>=count)
         emulate_printf("   ");
@@ -406,7 +412,7 @@ void show_word(size_t low, size_t high) {
 static void strip(char line[]) {
   int32 n;
   n = strlen(line);
-  if (n!=0) {	/* Delete trailing rubbish */
+  if (n!=0) {   /* Delete trailing rubbish */
     do
       n--;
     while (n>=0 && isspace(line[n]));
@@ -429,9 +435,12 @@ boolean read_line(char line[], int32 linelen) {
   readstate result;
   line[0] = asc_NUL;
   result = kbd_readline(line, linelen, 0);
-  result = READ_OK;	/* temp'y bodge */
-  if (result==READ_ESC || basicvars.escape) error(ERR_ESCAPE);
-  if (result==READ_EOF) return FALSE;		/* Read failed - Hit EOF */
+  //result = READ_OK;     /* temp'y bodge */
+  if (result==-READ_ESC || basicvars.escape) {
+    error(ERR_ESCAPE);
+    return FALSE;
+  }
+  if (result==-READ_EOF) return FALSE;           /* Read failed - Hit EOF */
   strip(line);
   return TRUE;
 }
@@ -449,9 +458,12 @@ boolean read_line(char line[], int32 linelen) {
 boolean amend_line(char line[], int32 linelen) {
   readstate result;
   result = kbd_readline(line, linelen,0);
-  result = READ_OK;	/* temp'y bodge */
-  if (result==READ_ESC || basicvars.escape) error(ERR_ESCAPE);
-  if (result==READ_EOF) return FALSE;		/* Read failed - Hit EOF */
+  //result = READ_OK;     /* temp'y bodge */
+  if (result==-READ_ESC || basicvars.escape) {
+    error(ERR_ESCAPE);
+    return FALSE;
+  }
+  if (result==-READ_EOF) return FALSE;           /* Read failed - Hit EOF */
   strip(line);
   return TRUE;
 }
@@ -462,8 +474,7 @@ boolean amend_line(char line[], int32 linelen) {
 ** ** THE FILENAME BUFFER MUST BE OF SUFFICIENT SIZE FOR USE BY tmpnam.
 ** ** NO CHECK IS MADE.
 */
-FILE *secure_tmpnam(char *name)
-{
+FILE *secure_tmpnam(char *name) {
 #ifdef TARGET_MINGW
   FILE *fdes;
   fdes=tmpfile();
@@ -490,8 +501,10 @@ int32 TOINT(float64 fltmp) {
 }
 
 int64 TOINT64(float64 fltmp) {
-  if (fltmp > MAXINT64FLT) error(ERR_RANGE);
-  if (fltmp < MININT64FLT) error(ERR_RANGE);
+  if ((fltmp > MAXINT64FLT) || (fltmp < MININT64FLT)) {
+    error(ERR_RANGE);
+    return 0;
+  }
   if ((sgni((int64)fltmp) != 0) && (sgnf(fltmp) != sgni((int64)fltmp))) error(ERR_RANGE);
   return (int64)fltmp;
 }
