@@ -190,8 +190,11 @@ static void *get_dladdr(size_t nameptr, void *libhandle, int32 xflag) {
 #ifdef TARGET_MINGW
   *(void **)(&dlsh)=rtrdlsym(libhandle, (void *)nameptr);
   if (dlsh == NULL) { 
-    if (!xflag) error(ERR_DL_NOSYM, "Symbol not found");
     dlsh = (void *)-1;
+    if (!xflag) {
+      error(ERR_DL_NOSYM, "Symbol not found");
+      return (dlsh);
+    }
   }
 #else
   *(void **)(&dlsh)=dlsym(libhandle, (void *)nameptr);
@@ -294,8 +297,8 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
       }
       break;
     case SWI_OS_Write0: /* This is extended in Brandy - normally all args apart
-			   from R0 are ignored; in Brandy, if R1 and R2 are set
-			   to 42, the text is output to the controlling terminal. */
+                           from R0 are ignored; in Brandy, if R1 and R2 are set
+                           to 42, the text is output to the controlling terminal. */
       outregs[0]=inregs[0].i+1+strlen((char *)(size_t)inregs[0].i);
       if ((inregs[1].i==42) && (inregs[2].i==42)) {
         fprintf(stderr,"%s\r\n", (char *)(size_t)inregs[0].i);
@@ -315,7 +318,10 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
       switch(inregs[0].i) {
         case 0: case 10:
           file_handle=fopen((char *)(size_t)inregs[1].i, "wb");
-          if (!file_handle) error(ERR_OPENWRITE);
+          if (!file_handle) {
+            error(ERR_OPENWRITE);
+            return;
+          }
           pointer = (char *)(size_t)inregs[4].i;
 #ifdef USE_SDL
           /* Mode 7 screen memory */
@@ -332,18 +338,30 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
           break;
         case 6:
           outregs[0]=0;
-          if (stat((char *)(size_t)inregs[1].i,&statbuf)) error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
+          if (stat((char *)(size_t)inregs[1].i,&statbuf)) {
+            error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
+            return;
+          }
           if (S_ISDIR(statbuf.st_mode)) {
             outregs[0]=2;
-            if (rmdir((char *)(size_t)inregs[1].i)) error(ERR_DIRNOTEMPTY);
+            if (rmdir((char *)(size_t)inregs[1].i)) {
+              error(ERR_DIRNOTEMPTY);
+              return;
+            }
           } else {
             outregs[0]=1;
-            if (unlink((char *)(size_t)inregs[1].i)) error(ERR_FILELOCKED);
+            if (unlink((char *)(size_t)inregs[1].i)) {
+              error(ERR_FILELOCKED);
+              return;
+            }
           }
           break;
         case 7: case 11:
           file_handle=fopen((char *)(size_t)inregs[1].i, "wb");
-          if (!file_handle) error(ERR_OPENWRITE);
+          if (!file_handle) {
+            error(ERR_OPENWRITE);
+            return;
+          }
           fclose(file_handle);
           break;
         case 8:
@@ -351,7 +369,10 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
 #ifndef TARGET_MINGW
           , 0777
 #endif
-          )) error(ERR_NODIR);
+          )) {
+            error(ERR_NODIR);
+            return;
+          }
           break;
         case 12: /* Should separate these out into the way they read the filename. */
         case 14:
@@ -359,7 +380,10 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
         case 255:
           outregs[0]=1;
           file_handle=fopen((char *)(size_t)inregs[1].i, "rb");
-          if (!file_handle) error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
+          if (!file_handle) {
+            error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
+            return;
+          }
           pointer = (char *)(size_t)inregs[2].i;
 #ifdef USE_SDL
           /* Mode 7 screen memory */
@@ -378,16 +402,21 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
           break;
         case 19:
           error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
-          break;
+          return;
         case 24:
 #ifdef TARGET_MINGW
           outregs[2]=65536; /* Dummy value, information is not available in Windows */
 #else
-          if (stat((char *)(size_t)inregs[1].i,&statbuf)) error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
+          if (stat((char *)(size_t)inregs[1].i,&statbuf)) {
+            error(ERR_NOTFOUND, (char *)(size_t)inregs[1].i);
+            return;
+          }
           outregs[2]=statbuf.st_blksize;
 #endif
           break;
-        default: error(ERR_BAD_OSFILE);
+        default: 
+          error(ERR_BAD_OSFILE);
+          return;
       }
       break;
     case SWI_OS_ReadLine:
@@ -399,7 +428,7 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
 // R4=b31-b24=reserved, b23-b16=reserved, b15-b8=reserved, b7-b0=echochar
 //
       inregs[4].i=(inregs[4].i & 0x00FFFFFF) | (inregs[0].i & 0xFF000000);
-      inregs[0].i=(inregs[0].i & 0x00FFFFFF);	/* Move flags to R4			*/
+      inregs[0].i=(inregs[0].i & 0x00FFFFFF);   /* Move flags to R4                     */
     case SWI_OS_ReadLine32:
 // R0=address
 // R1=length (buffer size-1)
@@ -410,8 +439,8 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
       *outstring='\0';
 //                       addr   length        lochar           hichar                     flags  echo
       a=kbd_readline(outstring, inregs[1].i+1, (inregs[2].i<<8) | (inregs[3].i<<16) | (inregs[4].i & 0xFF0000FF));
-      outregs[1]=a;				/* Returned length			*/
-						/* Should also set Carry if Escape	*/
+      outregs[1]=a;                             /* Returned length                      */
+                                                /* Should also set Carry if Escape      */
       outregs[0]=(size_t)outstring;
       break;
     case SWI_OS_GetEnv:
@@ -465,9 +494,9 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
     case SWI_OS_Plot:
       emulate_plot(inregs[0].i, inregs[1].i, inregs[2].i);
       break;
-    case SWI_OS_WriteN:	/* This is extended in Brandy - normally only R0 and R1
-			   are acted upon; in Brandy, if R2 is set to 42, the
-			   characters are output to the controlling terminal. */
+    case SWI_OS_WriteN: /* This is extended in Brandy - normally only R0 and R1
+                           are acted upon; in Brandy, if R2 is set to 42, the
+                           characters are output to the controlling terminal. */
       outregs[0]=inregs[0].i;
       if (inregs[2].i==42) {
         for (a=0; a<inregs[1].i; a++) fprintf(stderr,"%c", *((byte *)(size_t)inregs[0].i+a));
@@ -475,20 +504,60 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
         for (a=0; a<inregs[1].i; a++) emulate_vdu(*((byte *)(size_t)inregs[0].i+a));
       }
       break;
+    case SWI_OS_SetECFOrigin:
+      /* Make this a no-op instead of an error */
+      break;
+    case SWI_OS_ReadSysInfo:
+      switch (inregs[0].i) {
+        case 0:
+          outregs[0]=1920*1080*4;
+          break;
+        case 1:
+          outregs[0]=matrixflags.startupmode;
+          outregs[1]=1;
+          break;
+        case 2:
+          outregs[0]=0xFFFFFF00;
+          break;
+        case 9:
+          *outstring='\0';
+          switch (inregs[1].i) {
+            case 0: case 6:
+              strncpy(outstring,"Matrix Brandy MOS V" BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL, 80);
+              break;
+            case 2:
+              strncpy(outstring,BRANDY_DATE, 80);
+              break;
+            case 7:
+              strncpy(outstring,"Unknown", 80);
+              break;
+          }
+          outregs[0]=(size_t)outstring;
+          break;
+      }
+      break;
+    case SWI_OS_SetColour:
+#ifdef USE_SDL
+      swi_os_setcolour(inregs[0].i, inregs[1].i);
+#endif /* USE_SDL */
+      break;
     case SWI_OS_ScreenMode:
 #ifdef USE_SDL
       outregs[0]=inregs[0].i;
       outregs[1]=inregs[1].i;
       switch (inregs[0].i) {
-        case 0: 	emulate_mode(inregs[1].i);break;
-        case 1: 	outregs[1]=emulate_modefn();break;
-        case 7: 	outregs[1]=get_maxbanks();break; /* MAXBANKS defined in graphsdl.c */
-        case 8: 	osbyte113(inregs[1].i);break;
-        case 9: 	osbyte112(inregs[1].i);break;
-        case 10:	screencopy(inregs[1].i, inregs[2].i);break;
+        case 0:         emulate_mode(inregs[1].i);break;
+        case 1:         outregs[1]=emulate_modefn();break;
+        case 7:         outregs[1]=MAXBANKS; break;
+        case 8:         osbyte113(inregs[1].i);break;
+        case 9:         osbyte112(inregs[1].i);break;
+        case 10:        screencopy(inregs[1].i, inregs[2].i);break;
       }
 #endif
       break;
+    case SWI_OS_Reset:
+      exit_interpreter(0);
+      break;
     case SWI_ColourTrans_SetGCOL:
       outregs[0]=emulate_gcolrgb(inregs[4].i, (inregs[3].i & 0x80), ((inregs[0].i >> 8) & 0xFF), ((inregs[0].i >> 16) & 0xFF), ((inregs[0].i >> 24) & 0xFF));
       outregs[2]=0; outregs[3]=inregs[3].i & 0x80; outregs[4]=inregs[4].i;
@@ -569,12 +638,12 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
 #ifdef USE_SDL
       /* R0=0 to read into R2 from offset R1, R0 nonzero to write R2 into offset R1 */
       if (inregs[1].i < matrixflags.modescreen_sz) {
-	if (inregs[0].i==0) {
-	  outregs[2]=*(uint32 *)(matrixflags.modescreen_ptr+(inregs[1].i*4));
-	} else {
-	  *(uint32 *)(matrixflags.modescreen_ptr+(inregs[1].i*4))=inregs[2].i;
-	  refresh_location(inregs[1].i);
-	}
+        if (inregs[0].i==0) {
+          outregs[2]=*(uint32 *)(matrixflags.modescreen_ptr+(inregs[1].i*4));
+        } else {
+          *(uint32 *)(matrixflags.modescreen_ptr+(inregs[1].i*4))=inregs[2].i;
+          refresh_location(inregs[1].i);
+        }
       }
 #endif
       break;
@@ -603,11 +672,15 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
     case SWI_Brandy_dlopen:
 #ifdef __clang__
       error(ERR_DL_NODL);
+      return;
 #else
 #if defined(TARGET_UNIX) || defined(TARGET_MINGW)
       outregs[0]=(size_t)dlopen((char *)(size_t)inregs[0].i, RTLD_NOW|RTLD_GLOBAL);
 #else
-      if (!xflag) error(ERR_DL_NODL);
+      if (!xflag) {
+        error(ERR_DL_NODL);
+        return;
+      }
       outregs[0]=0;
 #endif /* TARGET_UNIX | TARGET_MINGW */
 #endif /* __clang__ */
@@ -615,6 +688,7 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
     case SWI_Brandy_dlcall:
 #ifdef __clang__
       error(ERR_DL_NODL);
+      return;
 #else
 #if defined(TARGET_UNIX) || defined(TARGET_MINGW)
       {
@@ -626,22 +700,37 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
         if (dlsh != (void *)-1) outregs[0]=do_syscall(dlsh, inregs);
       }
 #else
-      if (!xflag) error(ERR_DL_NODL);
+      if (!xflag) {
+        error(ERR_DL_NODL);
+        return;
+      }
       outregs[0]=0;
 #endif /* TARGET_UNIX | TARGET_MINGW */
 #endif /* __clang__ */
       break;
     case SWI_Brandy_MAlloc:
         outregs[0]=(size_t)malloc((size_t)inregs[0].i);
-        if (!xflag && outregs[0] == 0) error(ERR_NOMEMORY);
+        if (!xflag && outregs[0] == 0) {
+          error(ERR_NOMEMORY);
+          return;
+        }
       break;
     case SWI_Brandy_Free:
-        if ((size_t)inregs[0].i == (size_t)basicvars.workspace) error(ERR_ADDREXCEPT); /* Don't be silly. */
+        if ((size_t)inregs[0].i == (size_t)basicvars.workspace) {
+          error(ERR_ADDREXCEPT); /* Don't be silly. */
+          return;
+        }
         if (matrixflags.gpio) {
-          if ((size_t)inregs[0].i == (size_t)matrixflags.gpiomem) error(ERR_ADDREXCEPT); /* Don't deallocate GPIO mmap */
+          if ((size_t)inregs[0].i == (size_t)matrixflags.gpiomem) {
+            error(ERR_ADDREXCEPT); /* Don't deallocate GPIO mmap */
+            return;
+          }
         }
 #ifdef USE_SDL
-        if ((size_t)inregs[0].i == (size_t)matrixflags.modescreen_ptr) error(ERR_ADDREXCEPT); /* Don't allow deallocation of screen memory */
+        if ((size_t)inregs[0].i == (size_t)matrixflags.modescreen_ptr) {
+          error(ERR_ADDREXCEPT); /* Don't allow deallocation of screen memory */
+          return;
+        }
 #endif
         free((void *)(size_t)inregs[0].i);
       break;
@@ -685,6 +774,7 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
     case SWI_Brandy_dlgetaddr:
 #ifdef __clang__
       error(ERR_DL_NODL);
+      return;
 #else
 #if defined(TARGET_UNIX) || defined(TARGET_MINGW)
         outregs[0]=(size_t)get_dladdr(inregs[0].i, (void *)(size_t)inregs[1].i, xflag);
@@ -697,6 +787,7 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
     case SWI_Brandy_dlcalladdr:
 #ifdef __clang__
       error(ERR_DL_NODL);
+      return;
 #else
 #if defined(TARGET_UNIX) || defined(TARGET_MINGW)
       {
@@ -709,10 +800,14 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
           outregs[0]=do_syscall(dlsh, inregs);
         } else {
           error(ERR_ADDREXCEPT);
+          return;
         }
       }
 #else
-      if (!xflag) error(ERR_DL_NODL);
+      if (!xflag) {
+        error(ERR_DL_NODL);
+        return;
+      }
       outregs[0]=0;
 #endif /* TARGET_UNIX | TARGET_MINGW */
 #endif /* __clang__ */
@@ -722,7 +817,10 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
       break;
     case SWI_Brandy_TranslateFNames:
       outregs[0]=matrixflags.translatefname;
-      if (inregs[0].i >= 0 && inregs[0].i <= 2) matrixflags.translatefname = inregs[0].i;
+      if (inregs[0].i <= 2) matrixflags.translatefname = inregs[0].i;
+      break;
+    case SWI_Brandy_MemSet:
+      memset((void *)inregs[0].i, inregs[2].i, inregs[1].i);
       break;
 // Raspberry Pi GPIO stuff below
     case SWI_RaspberryPi_GPIOInfo:
@@ -734,26 +832,26 @@ void mos_sys_ext(size_t swino, sysparm inregs[], size_t outregs[], int32 xflag,
       outregs[2]=0;
       outregs[3]=0;
       if (NULL == file_handle) {
-	strncpy(outstring, "No machine type detected",25);
+        strncpy(outstring, "No machine type detected",25);
       } else {
-	if(fgets(outstring, 65534, file_handle))
-	  ;
-	fclose(file_handle);
-	file_handle=fopen("/proc/device-tree/system/linux,revision","r");
-	if (NULL != file_handle) {
-	  outregs[2]=(fgetc(file_handle) << 24);
-	  outregs[2]+=(fgetc(file_handle) << 16);
-	  outregs[2]+=(fgetc(file_handle) << 8);
-	  outregs[2]+=fgetc(file_handle);
-	  if (outregs[2] < 256) {
-	    outregs[0]=mossys_getboardfrommodel(outregs[2]);
-	    outregs[3]=gpio2rpi(outregs[0]);
-	  } else {
-	    outregs[3]=((outregs[2] & 0xFF0) >> 4);
-	    outregs[0]=rpi2gpio(outregs[3]);
-	  }
-	  fclose(file_handle);
-	}
+        if(fgets(outstring, 65534, file_handle))
+          ;
+        fclose(file_handle);
+        file_handle=fopen("/proc/device-tree/system/linux,revision","r");
+        if (NULL != file_handle) {
+          outregs[2]=(fgetc(file_handle) << 24);
+          outregs[2]+=(fgetc(file_handle) << 16);
+          outregs[2]+=(fgetc(file_handle) << 8);
+          outregs[2]+=fgetc(file_handle);
+          if (outregs[2] < 256) {
+            outregs[0]=mossys_getboardfrommodel(outregs[2]);
+            outregs[3]=gpio2rpi(outregs[0]);
+          } else {
+            outregs[3]=((outregs[2] & 0xFF0) >> 4);
+            outregs[0]=rpi2gpio(outregs[3]);
+          }
+          fclose(file_handle);
+        }
       }
       outregs[1]=(size_t)outstring;
       break;
