@@ -19,8 +19,8 @@
 ** Boston, MA 02111-1307, USA.
 **
 **
-**	This file contains various functions that are used to manipulate the
-**	Basic stack
+**      This file contains various functions that are used to manipulate the
+**      Basic stack
 */
 
 #include <string.h>
@@ -58,25 +58,33 @@ static void restore(int32 parmcount);
 
 /*
 ** 'entrysize' gives the size of each type of entry possible on the
-** basic stack
+** BASIC stack
 */
-static int32 entrysize [] = {
-  0,			0,    ALIGNSIZE(stack_uint8),     ALIGNSIZE(stack_int),       ALIGNSIZE(stack_int64),		/* 04 */
-  ALIGNSIZE(stack_float),     ALIGNSIZE(stack_string),    ALIGNSIZE(stack_string),    ALIGNSIZE(stack_array),		/* 08 */
-  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),     ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),		/* 0C */
-  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),     ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),		/* 10 */
-  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_locarray),  ALIGNSIZE(stack_locarray),  ALIGNSIZE(stack_gosub),		/* 14 */
-  ALIGNSIZE(stack_proc),      ALIGNSIZE(stack_fn),        ALIGNSIZE(stack_local),     ALIGNSIZE(stack_retparm),		/* 18 */
-  ALIGNSIZE(stack_while),     ALIGNSIZE(stack_repeat),    ALIGNSIZE(stack_for),       ALIGNSIZE(stack_for),		/* 1C */
-  ALIGNSIZE(stack_for),       ALIGNSIZE(stack_error),     ALIGNSIZE(stack_data),      ALIGNSIZE(stack_opstack),		/* 20 */
-  ALIGNSIZE(stack_restart)												/* 21 */
+static int32 entrysize [] = { 0,
+  0,                          ALIGNSIZE(stack_uint8),           /* 02 */
+  ALIGNSIZE(stack_int),       ALIGNSIZE(stack_int64),           /* 04 */
+  ALIGNSIZE(stack_float),     ALIGNSIZE(stack_string),          /* 06 */
+  ALIGNSIZE(stack_string),    ALIGNSIZE(stack_array),           /* 08 */
+  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),           /* 0A */
+  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),           /* 0C */
+  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),           /* 0E */
+  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_array),           /* 10 */
+  ALIGNSIZE(stack_arraytemp), ALIGNSIZE(stack_locarray),        /* 12 */
+  ALIGNSIZE(stack_locarray),  ALIGNSIZE(stack_gosub),           /* 14 */
+  ALIGNSIZE(stack_proc),      ALIGNSIZE(stack_fn),              /* 16 */
+  ALIGNSIZE(stack_local),     ALIGNSIZE(stack_retparm),         /* 18 */
+  ALIGNSIZE(stack_while),     ALIGNSIZE(stack_repeat),          /* 1A */
+  ALIGNSIZE(stack_for),       ALIGNSIZE(stack_for),             /* 1C */
+  ALIGNSIZE(stack_for),       ALIGNSIZE(stack_error),           /* 1E */
+  ALIGNSIZE(stack_data),      ALIGNSIZE(stack_opstack),         /* 20 */
+  ALIGNSIZE(stack_restart)                                                                                              /* 21 */
 };
 
 /*
 ** This table says which types of entries can be simply discarded
 ** from the Basic stack
 */
-static boolean disposible [] = {
+static boolean disposable [] = {
   FALSE, TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,
   TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,
   TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,  TRUE,
@@ -90,40 +98,40 @@ static char entry [64];
 
 static char *entryname(stackitem what) {
   switch (what) {
-    case STACK_UNKNOWN:		return "<unknown>";
-    case STACK_LVALUE:		return "lvalue";
-    case STACK_UINT8:		return "uint8";
-    case STACK_INT:		return "integer";
-    case STACK_INT64:		return "int64";
-    case STACK_FLOAT:		return "floating point";
-    case STACK_STRING:		return "string";
-    case STACK_STRTEMP:		return "temporary string";
-    case STACK_INTARRAY:	return "ineger array";
-    case STACK_IATEMP:		return "temp integer array";
-    case STACK_UINT8ARRAY:	return "uint8 array";
-    case STACK_U8ATEMP:		return "temp uint8 array";
-    case STACK_INT64ARRAY:	return "int64 array";
-    case STACK_I64ATEMP:	return "temp int64 array";
-    case STACK_FLOATARRAY:	return "floating point array";
-    case STACK_FATEMP:		return "temp floating point array";
-    case STACK_STRARRAY:	return "string array";
-    case STACK_SATEMP:		return "temp string array";
-    case STACK_LOCARRAY:	return "local array";
-    case STACK_LOCSTRING:	return "local string array";
-    case STACK_GOSUB:		return "GOSUB";
-    case STACK_PROC:		return "PROC";
-    case STACK_FN:		return "FN";
-    case STACK_LOCAL:		return "local variable";
-    case STACK_RETPARM:		return "return parameter";
-    case STACK_WHILE:		return "WHILE";
-    case STACK_REPEAT:		return "REPEAT";
-    case STACK_INTFOR:		return "integer FOR";
-    case STACK_INT64FOR:	return "int64 FOR";
-    case STACK_FLOATFOR:	return "floating point FOR";
-    case STACK_ERROR:		return "ON ERROR";
-    case STACK_DATA:		return "DATA";
-    case STACK_OPSTACK:		return "operator stack";
-    case STACK_RESTART:		return "siglongjmp block";
+    case STACK_UNKNOWN:         return "<unknown>";
+    case STACK_LVALUE:          return "lvalue";
+    case STACK_UINT8:           return "uint8";
+    case STACK_INT:             return "integer";
+    case STACK_INT64:           return "int64";
+    case STACK_FLOAT:           return "floating point";
+    case STACK_STRING:          return "string";
+    case STACK_STRTEMP:         return "temporary string";
+    case STACK_INTARRAY:        return "ineger array";
+    case STACK_IATEMP:          return "temp integer array";
+    case STACK_UINT8ARRAY:      return "uint8 array";
+    case STACK_U8ATEMP:         return "temp uint8 array";
+    case STACK_INT64ARRAY:      return "int64 array";
+    case STACK_I64ATEMP:        return "temp int64 array";
+    case STACK_FLOATARRAY:      return "floating point array";
+    case STACK_FATEMP:          return "temp floating point array";
+    case STACK_STRARRAY:        return "string array";
+    case STACK_SATEMP:          return "temp string array";
+    case STACK_LOCARRAY:        return "local array";
+    case STACK_LOCSTRING:       return "local string array";
+    case STACK_GOSUB:           return "GOSUB";
+    case STACK_PROC:            return "PROC";
+    case STACK_FN:              return "FN";
+    case STACK_LOCAL:           return "local variable";
+    case STACK_RETPARM:         return "return parameter";
+    case STACK_WHILE:           return "WHILE";
+    case STACK_REPEAT:          return "REPEAT";
+    case STACK_INTFOR:          return "integer FOR";
+    case STACK_INT64FOR:        return "int64 FOR";
+    case STACK_FLOATFOR:        return "floating point FOR";
+    case STACK_ERROR:           return "ON ERROR";
+    case STACK_DATA:            return "DATA";
+    case STACK_OPSTACK:         return "operator stack";
+    case STACK_RESTART:         return "siglongjmp block";
     default:
     sprintf(entry, "** Bad type %X **", what);
     return entry;
@@ -144,16 +152,6 @@ void dump(byte *sp) {
 
 #endif
 
-/*
-** 'safestack' returns TRUE if it is safe to move the Basic stack.
-** At the moment this is only allowed if the stack is empty, that is,
-** the only thing on it is the operator stack and the program is not
-** in a procedure or function
-*/
-boolean safestack(void) {
-  return basicvars.procstack==NIL && basicvars.stacktop.intsp->itemtype==STACK_OPSTACK;
-}
-
 /*
 ** 'make_opstack' is called to create a new operator stack. It also
 ** checks that there is enough room on the Basic stack to hold
@@ -165,7 +163,10 @@ size_t *make_opstack(void) {
 #ifdef DEBUG
   if (basicvars.debug_flags.stack) fprintf(stderr, "stack.c:make_opstack: stacktop=%p, stacklimit=%p, OPSTACKSIZE*LARGEST_ENTRY=%lX\n", basicvars.stacktop.bytesp, basicvars.stacklimit.bytesp, (long unsigned int)OPSTACKSIZE*LARGEST_ENTRY);
 #endif
-  if (basicvars.stacktop.bytesp-OPSTACKSIZE*LARGEST_ENTRY<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp-OPSTACKSIZE*LARGEST_ENTRY<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return NULL;
+  }
   basicvars.stacktop.opstacksp->itemtype = STACK_OPSTACK;
 #ifdef DEBUG
   if (basicvars.debug_flags.stack) fprintf(stderr, "Create operator stack at %p\n", basicvars.stacktop.bytesp);
@@ -181,7 +182,10 @@ size_t *make_opstack(void) {
 */
 sigjmp_buf *make_restart(void) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_restart);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return NULL;
+  }
   basicvars.stacktop.restartsp->itemtype = STACK_RESTART;
 #ifdef DEBUG
   if (basicvars.debug_flags.stack) fprintf(stderr, "Create restart block at %p\n", basicvars.stacktop.bytesp);
@@ -189,31 +193,18 @@ sigjmp_buf *make_restart(void) {
   return &basicvars.stacktop.restartsp->restart;
 }
 
-/*
-** 'get_topitem' returns the type of the top item on the Basic stack
-*/
-stackitem get_topitem(void) {
-  return basicvars.stacktop.intsp->itemtype;
-}
-
-/*
-** 'get_stacktop' returns the current value of the Basic stack pointer
-*/
-byte *get_stacktop(void) {
-  return basicvars.stacktop.bytesp;
-}
-
 /*
 ** 'get_safestack' returns the value that the stack pointer is set
 ** to after an error to restore the stack to a known condition
 */
+#if 0 /* Code disabled; only used in one place and it's a global struct variable */
 byte *get_safestack(void) {
 #ifdef DEBUG
   if (basicvars.debug_flags.stack) fprintf(stderr, "Get safestack = %p\n", basicvars.safestack.bytesp);
 #endif
   return basicvars.safestack.bytesp;
 }
-
+#endif
 
 /* Pushes an int of variable size, using the most appropriate type */
 void push_varyint(int64 value) {
@@ -341,12 +332,12 @@ void push_dolstring(int32 strlength, char *strtext) {
 #endif
 }
 
-static stackitem arraytype [] = {	/* Variable type -> array type */
+static stackitem arraytype [] = {       /* Variable type -> array type */
   STACK_UNKNOWN, STACK_UNKNOWN, STACK_INTARRAY, STACK_FLOATARRAY,
   STACK_STRARRAY, STACK_UNKNOWN, STACK_INT64ARRAY, STACK_UINT8ARRAY
 };
 
-static stackitem arraytemptype [] = {	/* Variable type -> temporary array type */
+static stackitem arraytemptype [] = {   /* Variable type -> temporary array type */
   STACK_UNKNOWN, STACK_UNKNOWN, STACK_IATEMP, STACK_FATEMP,
   STACK_SATEMP, STACK_UNKNOWN, STACK_I64ATEMP, STACK_U8ATEMP
 };
@@ -383,7 +374,10 @@ void push_arraytemp(basicarray *descriptor, int32 type) {
 */
 void push_proc(char *name, int32 count) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_proc);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.procsp->itemtype = STACK_PROC;
   basicvars.stacktop.procsp->fnprocblock.lastcall = basicvars.procstack;
   basicvars.stacktop.procsp->fnprocblock.retaddr = basicvars.current;
@@ -400,7 +394,10 @@ void push_proc(char *name, int32 count) {
 */
 void push_fn(char *name, int32 count) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_fn);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.fnsp->itemtype = STACK_FN;
   basicvars.stacktop.fnsp->lastopstop = basicvars.opstop;
   basicvars.stacktop.fnsp->lastopstlimit = basicvars.opstlimit;
@@ -420,7 +417,10 @@ void push_fn(char *name, int32 count) {
 */
 void push_gosub(void) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_gosub);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.gosubsp->itemtype = STACK_GOSUB;
   basicvars.stacktop.gosubsp->gosublock.lastcall = basicvars.gosubstack;
   basicvars.stacktop.gosubsp->gosublock.retaddr = basicvars.current;
@@ -444,16 +444,12 @@ void *alloc_stackmem(size_t size) {
   size = ALIGN(size);
   base = basicvars.stacktop.bytesp-size;
   p = base-ALIGNSIZE(stack_locarray);
-  if (p<basicvars.stacklimit.bytesp) return NIL;	/* Bail out if there is no room */
-  basicvars.stacktop.bytesp = p;	/* Reset the stack pointer */
+  if (p<basicvars.stacklimit.bytesp) return NIL;        /* Bail out if there is no room */
+  basicvars.stacktop.bytesp = p;        /* Reset the stack pointer */
   basicvars.stacktop.locarraysp->itemtype = STACK_LOCARRAY;
   basicvars.stacktop.locarraysp->arraysize = size;
 #ifdef DEBUG
-#  ifdef MATRIX64BIT
-  if (basicvars.debug_flags.stack) fprintf(stderr, "Allocate memory on stack at %p, size=%ld\n", p, size);
-#  else
-  if (basicvars.debug_flags.stack) fprintf(stderr, "Allocate memory on stack at %p, size=%d\n", p, size);
-#  endif
+  if (basicvars.debug_flags.stack) fprintf(stderr, "Allocate memory on stack at %p, size=%lld\n", p, (int64)size);
 #endif
   return base;
 }
@@ -484,7 +480,10 @@ void free_stackmem(void) {
 */
 void push_while(byte *expr) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_while);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.whilesp->itemtype = STACK_WHILE;
   basicvars.stacktop.whilesp->whilexpr = expr;
   basicvars.stacktop.whilesp->whileaddr = basicvars.current;
@@ -498,7 +497,10 @@ void push_while(byte *expr) {
 */
 void push_repeat(void) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_repeat);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.repeatsp->itemtype = STACK_REPEAT;
   basicvars.stacktop.repeatsp->repeataddr = basicvars.current;
 #ifdef DEBUG
@@ -512,7 +514,10 @@ void push_repeat(void) {
 */
 void push_intfor(lvalue forvar, byte *foraddr, int32 limit, int32 step, boolean simple) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_for);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.forsp->itemtype = STACK_INTFOR;
   basicvars.stacktop.forsp->simplefor = simple;
   basicvars.stacktop.forsp->forvar = forvar;
@@ -530,7 +535,10 @@ void push_intfor(lvalue forvar, byte *foraddr, int32 limit, int32 step, boolean
 */
 void push_int64for(lvalue forvar, byte *foraddr, int64 limit, int64 step, boolean simple) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_for);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.forsp->itemtype = STACK_INT64FOR;
   basicvars.stacktop.forsp->simplefor = simple;
   basicvars.stacktop.forsp->forvar = forvar;
@@ -548,7 +556,10 @@ void push_int64for(lvalue forvar, byte *foraddr, int64 limit, int64 step, boolea
 */
 void push_floatfor(lvalue forvar, byte *foraddr, float64 limit, float64 step, boolean simple) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_for);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.forsp->itemtype = STACK_FLOATFOR;
   basicvars.stacktop.forsp->simplefor = simple;
   basicvars.stacktop.forsp->forvar = forvar;
@@ -566,7 +577,10 @@ void push_floatfor(lvalue forvar, byte *foraddr, float64 limit, float64 step, bo
 */
 void push_data(byte *address) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_data);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.datasp->itemtype = STACK_DATA;
   basicvars.stacktop.datasp->address = address;
 #ifdef DEBUG
@@ -580,7 +594,10 @@ void push_data(byte *address) {
 */
 void push_error(errorblock handler) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_error);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.errorsp->itemtype = STACK_ERROR;
   basicvars.stacktop.errorsp->handler = handler;
 #ifdef DEBUG
@@ -594,7 +611,10 @@ void push_error(errorblock handler) {
 */
 void save_int(lvalue details, int32 value) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_local);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.localsp->itemtype = STACK_LOCAL;
   basicvars.stacktop.localsp->savedetails = details;
   basicvars.stacktop.localsp->value.savedint = value;
@@ -610,7 +630,10 @@ void save_int(lvalue details, int32 value) {
 */
 void save_uint8(lvalue details, uint8 value) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_local);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.localsp->itemtype = STACK_LOCAL;
   basicvars.stacktop.localsp->savedetails = details;
   basicvars.stacktop.localsp->value.saveduint8 = value;
@@ -626,7 +649,10 @@ void save_uint8(lvalue details, uint8 value) {
 */
 void save_int64(lvalue details, int64 value) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_local);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.localsp->itemtype = STACK_LOCAL;
   basicvars.stacktop.localsp->savedetails = details;
   basicvars.stacktop.localsp->value.savedint64 = value;
@@ -642,7 +668,10 @@ void save_int64(lvalue details, int64 value) {
 */
 void save_float(lvalue details, float64 floatvalue) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_local);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.localsp->itemtype = STACK_LOCAL;
   basicvars.stacktop.localsp->savedetails = details;
   basicvars.stacktop.localsp->value.savedfloat = floatvalue;
@@ -663,7 +692,10 @@ void save_float(lvalue details, float64 floatvalue) {
 */
 void save_string(lvalue details, basicstring thestring) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_local);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.localsp->itemtype = STACK_LOCAL;
   basicvars.stacktop.localsp->savedetails = details;
   basicvars.stacktop.localsp->value.savedstring = thestring;
@@ -679,7 +711,10 @@ void save_string(lvalue details, basicstring thestring) {
 */
 void save_array(lvalue details) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_local);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.localsp->itemtype = STACK_LOCAL;
   basicvars.stacktop.localsp->savedetails = details;
   basicvars.stacktop.localsp->value.savedarray = *details.address.arrayaddr;
@@ -698,7 +733,10 @@ void save_array(lvalue details) {
 */
 void save_retint(lvalue retdetails, lvalue details, int32 value) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_retparm);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.retparmsp->itemtype = STACK_RETPARM;
   basicvars.stacktop.retparmsp->retdetails = retdetails;
   basicvars.stacktop.retparmsp->savedetails = details;
@@ -715,7 +753,10 @@ void save_retint(lvalue retdetails, lvalue details, int32 value) {
 */
 void save_retuint8(lvalue retdetails, lvalue details, uint8 value) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_retparm);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.retparmsp->itemtype = STACK_RETPARM;
   basicvars.stacktop.retparmsp->retdetails = retdetails;
   basicvars.stacktop.retparmsp->savedetails = details;
@@ -732,7 +773,10 @@ void save_retuint8(lvalue retdetails, lvalue details, uint8 value) {
 */
 void save_retint64(lvalue retdetails, lvalue details, int64 value) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_retparm);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.retparmsp->itemtype = STACK_RETPARM;
   basicvars.stacktop.retparmsp->retdetails = retdetails;
   basicvars.stacktop.retparmsp->savedetails = details;
@@ -749,7 +793,10 @@ void save_retint64(lvalue retdetails, lvalue details, int64 value) {
 */
 void save_retfloat(lvalue retdetails, lvalue details, float64 floatvalue) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_retparm);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.retparmsp->itemtype = STACK_RETPARM;
   basicvars.stacktop.retparmsp->retdetails = retdetails;
   basicvars.stacktop.retparmsp->savedetails = details;
@@ -771,7 +818,10 @@ void save_retfloat(lvalue retdetails, lvalue details, float64 floatvalue) {
 */
 void save_retstring(lvalue retdetails, lvalue details, basicstring thestring) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_retparm);
-  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) error(ERR_STACKFULL);
+  if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
+    error(ERR_STACKFULL);
+    return;
+  }
   basicvars.stacktop.retparmsp->itemtype = STACK_RETPARM;
   basicvars.stacktop.retparmsp->retdetails = retdetails;
   basicvars.stacktop.retparmsp->savedetails = details;
@@ -793,67 +843,68 @@ static void restore_retparm(int32 parmcount) {
   int32 vartype = 0, intvalue = 0;
   float64 floatvalue = 0.0;
   basicstring stringvalue = {0, NULL};
-  p = basicvars.stacktop.retparmsp;	/* Not needed, but the code is unreadable otherwise */
+  p = basicvars.stacktop.retparmsp;     /* Not needed, but the code is unreadable otherwise */
 #ifdef DEBUG
   if (basicvars.debug_flags.stack) fprintf(stderr, "Restoring RETURN variable at %p from %p, return dest=%p\n",
    p->savedetails.address.intaddr, p, p->retdetails.address.intaddr);
 #endif
   basicvars.stacktop.retparmsp++;
-  switch (p->savedetails.typeinfo & PARMTYPEMASK) {	/* Fetch value from local variable and restore local var */
-  case VAR_INTWORD:	/* Integer variable */
-    intvalue = *p->savedetails.address.intaddr;		/* Fetch current value of local variable */
-    *p->savedetails.address.intaddr = p->value.savedint;	/* Restore local variable to its old value */
+  switch (p->savedetails.typeinfo & PARMTYPEMASK) {     /* Fetch value from local variable and restore local var */
+  case VAR_INTWORD:     /* Integer variable */
+    intvalue = *p->savedetails.address.intaddr;         /* Fetch current value of local variable */
+    *p->savedetails.address.intaddr = p->value.savedint;        /* Restore local variable to its old value */
     vartype = VAR_INTWORD;
     break;
-  case VAR_FLOAT:	/* Floating point variable */
+  case VAR_FLOAT:       /* Floating point variable */
     floatvalue = *p->savedetails.address.floataddr;
     *p->savedetails.address.floataddr = p->value.savedfloat;
     vartype = VAR_FLOAT;
     break;
-  case VAR_STRINGDOL:	/* String variable */
+  case VAR_STRINGDOL:   /* String variable */
     stringvalue = *p->savedetails.address.straddr;
     *p->savedetails.address.straddr = p->value.savedstring;
     vartype = VAR_STRINGDOL;
     break;
-  case VAR_INTBYTEPTR:	/* Indirect byte integer variable */
+  case VAR_INTBYTEPTR:  /* Indirect byte integer variable */
     intvalue = basicvars.memory[p->savedetails.address.offset];
     basicvars.memory[p->savedetails.address.offset] = p->value.savedint;
     vartype = VAR_INTWORD;
     break;
-  case VAR_INTWORDPTR:	/* Indirect word integer variable */
+  case VAR_INTWORDPTR:  /* Indirect word integer variable */
     intvalue = get_integer(p->savedetails.address.offset);
     store_integer(p->savedetails.address.offset, p->value.savedint);
     vartype = VAR_INTWORD;
     break;
-  case VAR_FLOATPTR:		/* Indirect floating point variable */
+  case VAR_FLOATPTR:            /* Indirect floating point variable */
     floatvalue = get_float(p->savedetails.address.offset);
     store_float(p->savedetails.address.offset, p->value.savedfloat);
     vartype = VAR_FLOAT;
     break;
-  case VAR_DOLSTRPTR:		/* Indirect string variable */
+  case VAR_DOLSTRPTR:           /* Indirect string variable */
     intvalue = stringvalue.stringlen = get_stringlen(p->savedetails.address.offset);
     stringvalue.stringaddr = alloc_string(intvalue);
     if (intvalue>0) memmove(stringvalue.stringaddr, &basicvars.memory[p->savedetails.address.offset], intvalue);
     memmove(&basicvars.memory[p->savedetails.address.offset], p->value.savedstring.stringaddr, p->value.savedstring.stringlen);
-    free_string(p->value.savedstring);		/* Discard saved copy of original '$ string' */
+    free_string(p->value.savedstring);          /* Discard saved copy of original '$ string' */
     vartype = VAR_DOLSTRPTR;
     break;
-  case VAR_INTARRAY: case VAR_INT64ARRAY: case VAR_UINT8ARRAY: case VAR_FLOATARRAY: case VAR_STRARRAY:	/* Array - Do nothing */
+  case VAR_INTARRAY: case VAR_INT64ARRAY: case VAR_UINT8ARRAY: case VAR_FLOATARRAY: case VAR_STRARRAY:  /* Array - Do nothing */
     break;
   default:
 #ifdef DEBUG
     fprintf(stderr,"stack.c:restore_retparm: Oops. Trying to switch on value &%X didn't work\n",(p->savedetails.typeinfo & PARMTYPEMASK));
 #endif
     error(ERR_BROKEN, __LINE__, "stack");
+    return;
   }
 
 /* Now restore the next parameter */
 
   parmcount--;
-  if (parmcount>0) {	/* There are still some parameters to do */
+  if (parmcount>0) {    /* There are still some parameters to do */
     if (basicvars.stacktop.intsp->itemtype==STACK_LOCAL)
       restore(parmcount);
-    else {	/* Must be a return parameter */
+    else {      /* Must be a return parameter */
       restore_retparm(parmcount);
     }
   }
@@ -882,12 +933,12 @@ static void restore_retparm(int32 parmcount) {
     break;
   case VAR_DOLSTRPTR:
     if (stringvalue.stringlen>0) memmove(&basicvars.memory[p->retdetails.address.offset], stringvalue.stringaddr, stringvalue.stringlen);
-    if (vartype==VAR_STRINGDOL) {	/* Local var was a normal string variable */
-      basicvars.memory[p->retdetails.address.offset+stringvalue.stringlen] = asc_CR;	/* So add a 'CR' at the end of the string */
+    if (vartype==VAR_STRINGDOL) {       /* Local var was a normal string variable */
+      basicvars.memory[p->retdetails.address.offset+stringvalue.stringlen] = asc_CR;    /* So add a 'CR' at the end of the string */
     }
     free_string(stringvalue);
     break;
-  case VAR_INTARRAY: case VAR_FLOATARRAY: case VAR_STRARRAY:	/* 'RETURN' dest is array - Do nothing */
+  case VAR_INTARRAY: case VAR_FLOATARRAY: case VAR_STRARRAY:    /* 'RETURN' dest is array - Do nothing */
     break;
   default:
     error(ERR_BROKEN, __LINE__, "stack");
@@ -906,7 +957,7 @@ static void restore(int32 parmcount) {
 #ifdef DEBUG
     if (basicvars.debug_flags.stack) fprintf(stderr, "Restoring variable at %p from %p\n", p->savedetails.address.intaddr, p);
 #endif
-    if (p->savedetails.typeinfo==VAR_INTWORD)	/* Deal with most common case first */
+    if (p->savedetails.typeinfo==VAR_INTWORD)   /* Deal with most common case first */
       *p->savedetails.address.intaddr = p->value.savedint;
     else {
       switch (p->savedetails.typeinfo & PARMTYPEMASK) {
@@ -941,6 +992,7 @@ static void restore(int32 parmcount) {
         break;
       default:
         error(ERR_BROKEN, __LINE__, "stack");
+        return;
       }
     }
 
@@ -1002,6 +1054,7 @@ int32 pop_int(void) {
   if (GET_TOPITEM != STACK_INT) {
     fprintf(stderr, "Error in stack.c:pop_int: Expected type %d, got %d instead\n", STACK_INT, GET_TOPITEM);
     error(ERR_BROKEN, __LINE__, "stack");
+    return 0;
   }
   basicvars.stacktop.bytesp+=ALIGNSIZE(stack_int);
 #ifdef DEBUG
@@ -1016,7 +1069,10 @@ uint8 pop_uint8(void) {
   if (basicvars.debug_flags.allstack) fprintf(stderr, "Pop uint8 integer from stack at %p, value %d\n",
    p, p->uint8value);
 #endif
-  if (GET_TOPITEM != STACK_UINT8) error(ERR_BROKEN, __LINE__, "stack");
+  if (GET_TOPITEM != STACK_UINT8) {
+    error(ERR_BROKEN, __LINE__, "stack");
+    return 0;
+  }
   basicvars.stacktop.bytesp+=ALIGNSIZE(stack_uint8);
 #ifdef DEBUG
   if (basicvars.debug_flags.allstack) fprintf(stderr, "pop_uint8: new SP at %p\n", basicvars.stacktop.bytesp);
@@ -1033,7 +1089,10 @@ int64 pop_int64(void) {
   if (basicvars.debug_flags.allstack) fprintf(stderr, "Pop 64-bit integer from stack at %p, value %lld\n",
    p, p->int64value);
 #endif
-  if (GET_TOPITEM != STACK_INT64) error(ERR_BROKEN, __LINE__, "stack");
+  if (GET_TOPITEM != STACK_INT64) {
+    error(ERR_BROKEN, __LINE__, "stack");
+    return 0;
+  }
   basicvars.stacktop.bytesp+=ALIGNSIZE(stack_int64);
 #ifdef DEBUG
   if (basicvars.debug_flags.allstack) fprintf(stderr, "pop_int64: new SP at %p\n", basicvars.stacktop.bytesp);
@@ -1084,12 +1143,12 @@ float64 pop_anynumfp(void) {
   return 0; /* Control never reaches here */
 }
 
-long double pop_anynumld(void) {
+float80 pop_anynumld(void) {
   switch(GET_TOPITEM) {
-    case STACK_INT: return (long double)pop_int();
-    case STACK_UINT8: return (long double)pop_uint8();
-    case STACK_INT64: return (long double)pop_int64();
-    case STACK_FLOAT: return (long double)pop_float();
+    case STACK_INT:   return (float80)pop_int();
+    case STACK_UINT8: return (float80)pop_uint8();
+    case STACK_INT64: return (float80)pop_int64();
+    case STACK_FLOAT: return (float80)pop_float();
     default: error(ERR_TYPENUM);
   }
   return 0; /* Control never reaches here */
@@ -1105,7 +1164,10 @@ float64 pop_float(void) {
   if (basicvars.debug_flags.allstack) fprintf(stderr, "Pop floating point value from stack at %p, value %g\n",
    p, p->floatvalue);
 #endif
-  if (GET_TOPITEM != STACK_FLOAT) error(ERR_BROKEN, __LINE__, "stack");
+  if (GET_TOPITEM != STACK_FLOAT) {
+    error(ERR_BROKEN, __LINE__, "stack");
+    return 0;
+  }
   basicvars.stacktop.bytesp+=ALIGNSIZE(stack_float);
 #ifdef DEBUG
   if (basicvars.debug_flags.allstack) fprintf(stderr, "pop_float: new SP at %p\n", basicvars.stacktop.bytesp);
@@ -1158,12 +1220,15 @@ basicarray pop_arraytemp(void) {
 */
 fnprocinfo pop_proc(void) {
   stack_proc *p = basicvars.stacktop.procsp;
-  if (p->itemtype != STACK_PROC) error(ERR_ENDPROC);
+  if (p->itemtype != STACK_PROC) {
+    error(ERR_ENDPROC);
+  } else {
 #ifdef DEBUG
-  if (basicvars.debug_flags.stack) fprintf(stderr, "Discard 'PROC' block at %p\n", p);
+    if (basicvars.debug_flags.stack) fprintf(stderr, "Discard 'PROC' block at %p\n", p);
 #endif
-  basicvars.procstack = p->fnprocblock.lastcall;
-  basicvars.stacktop.bytesp+=ALIGNSIZE(stack_proc);
+    basicvars.procstack = p->fnprocblock.lastcall;
+    basicvars.stacktop.bytesp+=ALIGNSIZE(stack_proc);
+  }
   return p->fnprocblock;
 }
 
@@ -1173,15 +1238,18 @@ fnprocinfo pop_proc(void) {
 */
 fnprocinfo pop_fn(void) {
   stack_fn *p = basicvars.stacktop.fnsp;
-  if (p->itemtype != STACK_FN) error(ERR_FNRETURN);
+  if (p->itemtype != STACK_FN) {
+    error(ERR_FNRETURN);
+  } else {
 #ifdef DEBUG
-  if (basicvars.debug_flags.stack) fprintf(stderr, "Discard 'FN' block at %p, restart = %p\n", p, p->lastrestart);
+    if (basicvars.debug_flags.stack) fprintf(stderr, "Discard 'FN' block at %p, restart = %p\n", p, p->lastrestart);
 #endif
-  basicvars.opstop = p->lastopstop;
-  basicvars.opstlimit = p->lastopstlimit;
-  basicvars.local_restart = p->lastrestart;
-  basicvars.procstack = p->fnprocblock.lastcall;
-  basicvars.stacktop.bytesp+=ALIGNSIZE(stack_fn);
+    basicvars.opstop = p->lastopstop;
+    basicvars.opstlimit = p->lastopstlimit;
+    basicvars.local_restart = p->lastrestart;
+    basicvars.procstack = p->fnprocblock.lastcall;
+    basicvars.stacktop.bytesp+=ALIGNSIZE(stack_fn);
+  }
   return p->fnprocblock;
 }
 
@@ -1191,12 +1259,15 @@ fnprocinfo pop_fn(void) {
 */
 gosubinfo pop_gosub(void) {
   stack_gosub *p = basicvars.stacktop.gosubsp;
-  if (p->itemtype != STACK_GOSUB) error(ERR_RETURN);
+  if (p->itemtype != STACK_GOSUB) {
+    error(ERR_RETURN);
+  } else {
 #ifdef DEBUG
-  if (basicvars.debug_flags.stack) fprintf(stderr, "Discard 'GOSUB' block at %p\n", p);
+    if (basicvars.debug_flags.stack) fprintf(stderr, "Discard 'GOSUB' block at %p\n", p);
 #endif
-  basicvars.gosubstack = p->gosublock.lastcall;
-  basicvars.stacktop.bytesp+=ALIGNSIZE(stack_gosub);
+    basicvars.gosubstack = p->gosublock.lastcall;
+    basicvars.stacktop.bytesp+=ALIGNSIZE(stack_gosub);
+  }
   return p->gosublock;
 }
 
@@ -1215,40 +1286,43 @@ static void discard(stackitem item, boolean restorevars) {
     temp = pop_string();
     free_string(temp);
     break;
-  case STACK_LOCAL: 	/* Restore local variable to its old value */
+  case STACK_LOCAL:     /* Restore local variable to its old value */
     if (restorevars) {
       restore(1);
     } else {
       dummyrestore(1);
     }
     break;
-  case STACK_RETPARM:	/* Deal with a 'return' parameter and restore local parameter */
+  case STACK_RETPARM:   /* Deal with a 'return' parameter and restore local parameter */
     restore_retparm(1);
     break;
-  case STACK_GOSUB:	/* Clear 'GOSUB' block from stack */
+  case STACK_GOSUB:     /* Clear 'GOSUB' block from stack */
     (void) pop_gosub();
     break;
-  case STACK_PROC:	/* Clear 'PROC' block */
+  case STACK_PROC:      /* Clear 'PROC' block */
     (void) pop_proc();
     break;
-  case STACK_FN:	/* Clear 'FN' block */
+  case STACK_FN:        /* Clear 'FN' block */
     (void) pop_fn();
     break;
-  case STACK_ERROR:	/* Restore old Basic error handler */
+  case STACK_ERROR:     /* Restore old Basic error handler */
     basicvars.error_handler = pop_error();
     break;
-  case STACK_DATA:	/* Restore old Basic data pointer */
+  case STACK_DATA:      /* Restore old Basic data pointer */
     basicvars.datacur = pop_data();
     break;
-  case STACK_LOCARRAY:	/* Local numeric array */
+  case STACK_LOCARRAY:  /* Local numeric array */
     basicvars.stacktop.bytesp+=entrysize[STACK_LOCARRAY]+basicvars.stacktop.locarraysp->arraysize;
     break;
-  case STACK_LOCSTRING:	/* Local string array */
+  case STACK_LOCSTRING: /* Local string array */
     discard_strings(basicvars.stacktop.bytesp+entrysize[STACK_LOCARRAY], basicvars.stacktop.locarraysp->arraysize);
     basicvars.stacktop.bytesp+=entrysize[STACK_LOCARRAY]+basicvars.stacktop.locarraysp->arraysize;
     break;
   default:
-    if (item==STACK_UNKNOWN || item>=STACK_HIGHEST) error(ERR_BROKEN, __LINE__, "stack");
+    if (item==STACK_UNKNOWN || item>=STACK_HIGHEST) {
+      error(ERR_BROKEN, __LINE__, "stack");
+      return;
+    }
     basicvars.stacktop.bytesp+=entrysize[item];
   }
 }
@@ -1260,7 +1334,7 @@ static void discard(stackitem item, boolean restorevars) {
 stack_while *get_while(void) {
   stackitem item;
   item = basicvars.stacktop.whilesp->itemtype;
-  while (disposible[item]) {
+  while (disposable[item]) {
     discard(item,1);
     item = basicvars.stacktop.whilesp->itemtype;
     if (item==STACK_WHILE) return basicvars.stacktop.whilesp;
@@ -1288,7 +1362,7 @@ void pop_while(void) {
 stack_repeat *get_repeat(void) {
   stackitem item;
   item = basicvars.stacktop.repeatsp->itemtype;
-  while (disposible[item]) {
+  while (disposable[item]) {
     discard(item,1);
     item = basicvars.stacktop.repeatsp->itemtype;
     if (item==STACK_REPEAT) return basicvars.stacktop.repeatsp;
@@ -1315,7 +1389,7 @@ void pop_repeat(void) {
 stack_for *get_for(void) {
   stackitem item;
   item = basicvars.stacktop.forsp->itemtype;
-  while (disposible[item]) {
+  while (disposable[item]) {
     discard(item,1);
     item = basicvars.stacktop.forsp->itemtype;
     if (item==STACK_INTFOR || item==STACK_FLOATFOR) return basicvars.stacktop.forsp;
@@ -1427,11 +1501,6 @@ void clear_stack(void) {
   basicvars.gosubstack = NIL;
 }
 
-boolean is8or32int(stackitem item) {
-  if ((item == STACK_INT) || (item == STACK_UINT8)) return 1;
-  return 0;
-}
-
 #ifdef DEBUG
 /* Output to stderr the stack item type supplied */
 void debug_show_stackitemtype(int32 item) {
