@@ -178,18 +178,17 @@ static byte colourmap [] = {
 
 #endif
 
-#ifndef NOTEKGFX
 /* Tektronix variables */
 static int32
-  xgupp = 2,			/* RISC OS graphic units per pixel in X direction */
-  ygupp = 2,			/* RISC OS graphic units per pixel in Y direction */
-  xlast,			/* Graphics X coordinate of last point visited */
-  ylast,			/* Graphics Y coordinate of last point visited */
-  xlast2,			/* Graphics X coordinate of last-but-one point visited */
-  ylast2,			/* Graphics Y coordinate of last-but-one point visited */
-  xorigin,			/* X coordinate of graphics origin */
-  yorigin,			/* Y coordinate of graphics origin */
-  graphicurs;			/* Text at graphics cursor */
+  xgupp = 2,                    /* RISC OS graphic units per pixel in X direction */
+  ygupp = 2,                    /* RISC OS graphic units per pixel in Y direction */
+  xlast,                        /* Graphics X coordinate of last point visited */
+  ylast,                        /* Graphics Y coordinate of last point visited */
+  xlast2,                       /* Graphics X coordinate of last-but-one point visited */
+  ylast2,                       /* Graphics Y coordinate of last-but-one point visited */
+  xorigin,                      /* X coordinate of graphics origin */
+  yorigin,                      /* Y coordinate of graphics origin */
+  graphicurs;                   /* Text at graphics cursor */
 #define MAX_XRES 16384
 #define MAX_YRES 16384
 #define FAST_2_MUL(x) ((x)<<1)
@@ -198,7 +197,6 @@ static int32
 #define FAST_4_DIV(x) ((x)>>2)
 
 static int32 geom_left[MAX_YRES], geom_right[MAX_YRES];
-#endif
 
 static unsigned int vduflag(unsigned int flags) {
   return (vduflags & flags) ? 1 : 0;
@@ -208,13 +206,11 @@ static void write_vduflag(unsigned int flags, int yesno) {
   vduflags = yesno ? vduflags | flags : vduflags & ~flags;
 }
 
-#ifndef NOTEKGFX
 static void tekvdu(int chr) {
   putchar(chr);
   fflush(stdout);
   if (matrixflags.tekspeed > 0) usleep(9000000/matrixflags.tekspeed);
 }
-#endif
 
 #ifdef USE_ANSI
 /*
@@ -225,9 +221,10 @@ static void tekvdu(int chr) {
 ** -- ANSI --
 */
 void find_cursor(void) {
-  int ch, column, row;
+  int column, row;
   column = row = 0;
   if (!basicvars.runflags.outredir && !basicvars.runflags.inredir) {
+    int ch;
     // set_esc_key(_POSIX_VDISABLE); /* Disable INTR */
     printf("\033[6n");  /* ANSI/VTxxx sequence to find the position of the cursor */
     fflush(stdout);
@@ -321,8 +318,8 @@ static void scroll_text(updown direction) {
 */
 static void textcolor(int32 colour) {
   printf("\033[");
-  if (colour & 8) printf("1;");		  /* bright     */
-  else            printf("11;");	  /* non-bright */
+  if (colour & 8) printf("1;");           /* bright     */
+  else            printf("11;");          /* non-bright */
   printf("%dm", colour+ANSI_FOREGROUND);  /* VTxxx/ANSI sequence to set the foreground colour */
 }
 
@@ -1046,6 +1043,7 @@ static void reset_colours(void) {
     break;
   default:      /* 32K and 16M colour depths are not supported */
     error(ERR_UNSUPPORTED);
+    return;
   }
   if (colourdepth==256)
     colourmask = COL256MASK;
@@ -1079,7 +1077,6 @@ static void vdu_hometext(void) {
   move_cursor(twinleft, twintop);
 }
 
-#ifndef NOTEKGFX
 static void tekinit(void) {
   if (!graphicurs) printf("%c%c%c%c%c%c", 27, 91, 63, 51, 56, 104);
 }
@@ -1088,17 +1085,15 @@ static void tekexit(void) {
 }
 
 static void vdu_cleargraph(void) {
-  if (! matrixflags.tekenabled) error(ERR_NOGRAPHICS);
+  if (! matrixflags.tekenabled) {
+    error(ERR_NOGRAPHICS);
+    return;
+  }
   tekinit();
   tekvdu(27);
   tekvdu(12);
   tekexit();
 }
-#else
-static void vdu_cleargraph(void) {
-  error(ERR_NOGRAPHICS);
-}
-#endif
 
 /*
 ** 'vdu_movetext' moves the text cursor to the given column and row in
@@ -1114,16 +1109,12 @@ static void vdu_movetext(void) {
 }
 
 static void vdu_origin(void) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   int32 x, y;
   
   x = vduqueue[0]+vduqueue[1]*256;
   y = vduqueue[2]+vduqueue[3]*256;
   xorigin = x<=32767 ? x : -(0x10000-x);
   yorigin = y<=32767 ? y : -(0x10000-y);
-#endif
 }
 
 
@@ -1196,10 +1187,10 @@ static void print_char(int32 charvalue) {
 static void vdu_plot(void) {
   int32 x, y;
   x = vduqueue[1]+vduqueue[2]*256;
-  if (x > 0x7FFF) x = -(0x10000-x);	/* X is negative */
+  if (x > 0x7FFF) x = -(0x10000-x);     /* X is negative */
   y = vduqueue[3]+vduqueue[4]*256;
-  if (y > 0x7FFF) y = -(0x10000-y);	/* Y is negative */
-  emulate_plot(vduqueue[0], x, y);	/* vduqueue[0] gives the plot code */
+  if (y > 0x7FFF) y = -(0x10000-y);     /* Y is negative */
+  emulate_plot(vduqueue[0], x, y);      /* vduqueue[0] gives the plot code */
 }
 
 /*
@@ -1252,19 +1243,16 @@ void emulate_vdu(int32 charvalue) {
     close_printer();
     break;
   case VDU_TEXTCURS:    /* 4 - Print text at text cursor (ignored) */
-#ifndef NOTEKGFX
     graphicurs = 0;
     if (matrixflags.tekenabled) tekexit();
-#endif
     break;
   case VDU_GRAPHICURS:  /* 5 - Print text at graphics cursor */
-#ifdef NOTEKGFX
-    error(ERR_NOGRAPHICS);
-#else
-    if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
+    if (!matrixflags.tekenabled) {
+      error(ERR_NOGRAPHICS);
+      return;
+    }
     tekinit();
     graphicurs = 1;
-#endif
     break;
   case VDU_BEEP:        /* 7 - Sound the bell */
     putch('\7');
@@ -1283,7 +1271,11 @@ void emulate_vdu(int32 charvalue) {
     move_curup();
     break;
   case VDU_CLEARTEXT:   /* 12 - Clear text window (formfeed) */
-    vdu_cleartext();
+    if (graphicurs) {
+      vdu_cleargraph();
+    } else {
+      vdu_cleartext();
+    }
     break;
   case VDU_RETURN:      /* 13 - Carriage return */
     vdu_return();
@@ -1295,14 +1287,10 @@ void emulate_vdu(int32 charvalue) {
     vdu_textcol();
     break;
   case VDU_GRAPHCOL:    /* 18 - Change current graphics colour */
-#ifdef NOTEKGFX
-    error(ERR_NOGRAPHICS);
-#else
     /* Tektronix can't erase apart from the whole screen.
     ** Make graphics colour changes a no-op instead of complaining. */
     if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
-#endif
-    break;
+    return;
   case VDU_LOGCOL:      /* 19 - Map logical colour to physical colour */
     vdu_setpalette();
     break;
@@ -1318,14 +1306,10 @@ void emulate_vdu(int32 charvalue) {
     vdu_23command();
     break;
   case VDU_DEFGRAPH:  /* 24 - Define graphics window */
-#ifdef NOTEKGFX
-    error(ERR_NOGRAPHICS);
-#else
     /* Possibly doable in part in the future by altering drawing commands.
     ** For now, a no-op. */
     if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
-#endif
-    break;
+    return;
   case VDU_PLOT:        /* 25 - Issue graphics command */
     vdu_plot();
     break;
@@ -1448,7 +1432,10 @@ static void setup_mode(int32 mode) {
   }
   else {
     if (mode>HIGHMODE) mode = modecopy = 0;     /* User-defined modes are mapped to mode 0 */
-    if (modetable[mode].xtext>SCRWIDTH && (!matrixflags.tekenabled)) error(ERR_BADMODE);
+    if (modetable[mode].xtext>SCRWIDTH && (!matrixflags.tekenabled)) {
+      error(ERR_BADMODE);
+      return;
+    }
 /* Set up VDU driver parameters for mode */
     screenmode = modecopy;
     colourdepth = modetable[mode].coldepth;
@@ -1498,10 +1485,8 @@ void emulate_mode(int32 mode) {
   textcolor(text_physforecol);
   textbackground(text_physbackcol);
   reset_screen();
-#ifndef NOTEKGFX
   graphicurs = 0;
   if (matrixflags.tekenabled) vdu_cleargraph();
-#endif
   clrscr();
 }
 
@@ -1512,19 +1497,22 @@ void emulate_mode(int32 mode) {
  */
 void emulate_newmode(int32 xres, int32 yres, int32 bpp, int32 rate) {
   int32 coldepth, n;
-  if (xres==0 || yres==0 || rate==0 || bpp==0) error(ERR_BADMODE);
+  if (xres==0 || yres==0 || rate==0 || bpp==0) {
+    error(ERR_BADMODE);
+    return;
+  }
   switch (bpp) {
-  case 1: coldepth = 2; break;
-  case 2: coldepth = 4; break;
-  case 4: coldepth = 16; break;
-  default:
-    coldepth = 256;
+    case 1: coldepth = 2; break;
+    case 2: coldepth = 4; break;
+    case 4: coldepth = 16; break;
+    default:
+      coldepth = 256;
   }
   for (n=0; n<=HIGHMODE; n++) {
     if (modetable[n].xres == xres && modetable[n].yres == yres && modetable[n].coldepth == coldepth) break;
   }
   if (n > HIGHMODE) error(ERR_BADMODE);
-  emulate_mode(n);
+  else emulate_mode(n);
 }
 
 /*
@@ -1534,13 +1522,16 @@ void emulate_newmode(int32 xres, int32 yres, int32 bpp, int32 rate) {
 */
 void emulate_modestr(int32 xres, int32 yres, int32 colours, int32 greys, int32 xeig, int32 yeig, int32 rate) {
   int32 coldepth, n;
-  if (xres==0 || yres==0 || rate==0 || (colours==0 && greys==0)) error(ERR_BADMODE);
+  if (xres==0 || yres==0 || rate==0 || (colours==0 && greys==0)) {
+    error(ERR_BADMODE);
+    return;
+  }
   coldepth = colours!=0 ? colours : greys;
   for (n=0; n<=HIGHMODE; n++) {
     if (modetable[n].xres==xres && modetable[n].yres==yres && modetable[n].coldepth==coldepth) break;
   }
   if (n>HIGHMODE) error(ERR_BADMODE);
-  emulate_mode(n);
+  else emulate_mode(n);
 }
 
 /*
@@ -1550,7 +1541,6 @@ int32 emulate_modefn(void) {
   return screenmode;
 }
 
-#ifndef NOTEKGFX
 /* Graphics primitives */
 static void plot_pixel(int32 px, int32 py) {
   int32 mx, my;
@@ -1666,8 +1656,8 @@ static void draw_line(int32 x1, int32 y1, int32 x2, int32 y2, int32 style) {
         if (skip) {
           skip=0;
         } else {
-	  plot_pixel(x, y);
-	  if (style & 0x10) skip=1;
+          plot_pixel(x, y);
+          if (style & 0x10) skip=1;
         }
         if (d >= 0) {
           y += sy;
@@ -1682,8 +1672,8 @@ static void draw_line(int32 x1, int32 y1, int32 x2, int32 y2, int32 style) {
         if (skip) {
           skip=0;
         } else {
-	  plot_pixel(x, y);
-	  if (style & 0x10) skip=1;
+          plot_pixel(x, y);
+          if (style & 0x10) skip=1;
         }
         if (d >= 0) {
           x += sx;
@@ -1809,24 +1799,22 @@ static void filled_ellipse(
   int32 shearx /* X shear */
 ) {
 
-  int32 x, y, width, aa, bb, aabb, ym, dx, si;
-  float64 s;
+  int32 y, width, aa, bb, aabb, ym, dx;
 
   aa = a * a;
   bb = b * b;
-  aabb=aa*bb;
+  aabb = aa * bb;
 
-  x = 0;
-  width=a;
+  width = a;
   dx = 0;
-  ym = y = b;
+  ym = b;
 
   draw_h_line(x0-a, y0, x0 + a);
 
   for (y=1; y <= b; y++) {
-    s=shearx*(1.0*y/ym);
-    si=s;
-    x=width-(dx-1);
+    float64 s=shearx*(1.0*y/ym);
+    int32 si=s;
+    int32 x=width-(dx-1);
     for (;x>0; x--)
       if (x*x*bb + y*y*aa < aabb) break;
     dx = width -x;
@@ -1845,36 +1833,39 @@ static void fill_rectangle(uint32 left, uint32 top, uint32 right, uint32 bottom)
 }
 
 /*
-** Version of 'emulate_plot' used when interpreter does not
-** include any graphics support
+** Version of 'emulate_plot' used when interpreter has limited graphics
+** support via Tektronix terminals
 */
 void emulate_plot(int32 code, int32 x, int32 y) {
   int32 xlast3, ylast3, sx, sy, ex, ey;
 
-  if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
+  if (!matrixflags.tekenabled) {
+    error(ERR_NOGRAPHICS);
+    return;
+  }
 /* Decode the command */
   tekinit();
   xlast3 = xlast2;
   ylast3 = ylast2;
   xlast2 = xlast;
   ylast2 = ylast;
-  if ((code & ABSCOORD_MASK) != 0 ) {		/* Coordinate (x,y) is absolute */
-    xlast = x+xorigin;	/* These probably have to be treated as 16-bit values */
+  if ((code & ABSCOORD_MASK) != 0 ) {           /* Coordinate (x,y) is absolute */
+    xlast = x+xorigin;  /* These probably have to be treated as 16-bit values */
     ylast = y+yorigin;
   }
-  else {	/* Coordinate (x,y) is relative */
-    xlast+=x;	/* These probably have to be treated as 16-bit values */
+  else {        /* Coordinate (x,y) is relative */
+    xlast+=x;   /* These probably have to be treated as 16-bit values */
     ylast+=y;
   }
   if ((code & PLOT_COLMASK) == PLOT_MOVEONLY) {
     tekexit();
-    return;	/* Just moving graphics cursor, so finish here */
+    return;     /* Just moving graphics cursor, so finish here */
   }
   sx = xlast2;
   sy = ylast2;
   ex = xlast;
   ey = ylast;
-  if ((code & GRAPHOP_MASK) != SHIFT_RECTANGLE) {		/* Move and copy rectangle are a special case */
+  if ((code & GRAPHOP_MASK) != SHIFT_RECTANGLE) {               /* Move and copy rectangle are a special case */
     /* Do nothing, not supported */
   }
   switch (code & GRAPHOP_MASK) {
@@ -1885,17 +1876,18 @@ void emulate_plot(int32 code, int32 x, int32 y) {
   case DRAW_SOLIDLINE2:
   case DRAW_SOLIDLINE2+8:
   case DRAW_DOTLINE2:
-  case DRAW_DOTLINE2+8: {	/* Draw line */
+  case DRAW_DOTLINE2+8: {       /* Draw line */
     draw_line(sx, sy, ex, ey, (code & DRAW_STYLEMASK));
     break;
   }
-  case PLOT_POINT:	/* Plot a single point */
+  case PLOT_POINT:      /* Plot a single point */
     plot_pixel(ex, ey);
     break;
-  case FILL_TRIANGLE: {		/* Plot a filled triangle */
-    int32 left, right, top, bottom;
+  case FILL_TRIANGLE: {         /* Plot a filled triangle */
+    // int32 left, right, top, bottom;
     filled_triangle(xlast3, ylast3, sx, sy, ex, ey);
 /*  Now figure out the coordinates of the rectangle that contains the triangle */
+#if 0 /* These might be useful for future expansion */
     left = right = xlast3;
     top = bottom = ylast3;
     if (xlast2 < left) left = xlast2;
@@ -1906,9 +1898,10 @@ void emulate_plot(int32 code, int32 x, int32 y) {
     if (ylast > top) top = ylast;
     if (ylast2 < bottom) bottom = ylast2;
     if (ylast < bottom) bottom = ylast;
+#endif
     break;
   }
-  case FILL_RECTANGLE: {		/* Plot a filled rectangle */
+  case FILL_RECTANGLE: {                /* Plot a filled rectangle */
     int32 left, right, top, bottom;
     left = sx;
     top = sy;
@@ -1921,18 +1914,20 @@ void emulate_plot(int32 code, int32 x, int32 y) {
     fill_rectangle(left, top, right, bottom);
     break;
   }
-  case FILL_PARALLELOGRAM: {	/* Plot a filled parallelogram */
-    int32 vx, vy, left, right, top, bottom;
+  case FILL_PARALLELOGRAM: {    /* Plot a filled parallelogram */
+    int32 vx, vy;
+    // int32 left, right, top, bottom;
     filled_triangle(xlast3, ylast3, sx, sy, ex, ey);
     vx = xlast3-xlast2+xlast;
     vy = ylast3-ylast2+ylast;
     filled_triangle(ex, ey, vx, vy, xlast3, ylast3);
 /*  Now figure out the coordinates of the rectangle that contains the parallelogram */
+#if 0 /* These might be useful for future expansion */
     left = right = xlast3;
     top = bottom = ylast3;
     if (xlast2 < left) left = xlast2;
     if (xlast < left) left = xlast;
-    if (vx < left) left = vx;
+     if (vx < left) left = vx;
     if (xlast2 > right) right = xlast2;
     if (xlast > right) right = xlast;
     if (vx > right) right = vx;
@@ -1942,10 +1937,11 @@ void emulate_plot(int32 code, int32 x, int32 y) {
     if (ylast2 < bottom) bottom = ylast2;
     if (ylast < bottom) bottom = ylast;
     if (vy < bottom) bottom = vy;
+#endif
     break;
   }
-  case PLOT_CIRCLE:		/* Plot the outline of a circle */
-  case FILL_CIRCLE: {		/* Plot a filled circle */
+  case PLOT_CIRCLE:             /* Plot the outline of a circle */
+  case FILL_CIRCLE: {           /* Plot a filled circle */
     int32 xradius, yradius, xr;
 /*
 ** (xlast2, ylast2) is the centre of the circle. (xlast, ylast) is a
@@ -1962,13 +1958,13 @@ void emulate_plot(int32 code, int32 x, int32 y) {
     }
     /* To match RISC OS, xlast needs to be the right-most point not left-most. */
     xlast+=(xr*2);
-    ex = sx-xradius;
-    ey = sy-yradius;
+//    ex = sx-xradius;
+//    ey = sy-yradius;
 /* (ex, ey) = coordinates of top left hand corner of the rectangle that contains the ellipse */
     break;
   }
-  case PLOT_ELLIPSE:		/* Draw an ellipse outline */
-  case FILL_ELLIPSE: {		/* Draw a filled ellipse */
+  case PLOT_ELLIPSE:            /* Draw an ellipse outline */
+  case FILL_ELLIPSE: {          /* Draw a filled ellipse */
     int32 semimajor, semiminor, shearx;
 /*
 ** (xlast3, ylast3) is the centre of the ellipse. (xlast2, ylast2) is a
@@ -1986,8 +1982,8 @@ void emulate_plot(int32 code, int32 x, int32 y) {
     else {
       filled_ellipse(sx, sy, semimajor, semiminor, shearx);
     }
-    ex = sx-semimajor;
-    ey = sy-semiminor;
+//    ex = sx-semimajor;
+//    ey = sy-semiminor;
 /* (ex, ey) = coordinates of top left hand corner of the rectangle that contains the ellipse */
     break;
   }
@@ -1997,12 +1993,6 @@ void emulate_plot(int32 code, int32 x, int32 y) {
   tekexit();
 }
 
-#else /* NOTEKGFX */
-void emulate_plot(int32 code, int32 x, int32 y) {
-  error(ERR_NOGRAPHICS);
-}
-#endif /* NOTEKGFX */
-
 /*
 ** Version of 'emulate_pointfn' used when interpreter does not
 ** include any graphics support
@@ -2103,13 +2093,9 @@ void emulate_tint(int32 action, int32 tint) {
 ** how the VDU drivers carry out graphics operations.
 */
 void emulate_gcol(int32 action, int32 colour, int32 tint) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   /* Tektronix can't erase apart from the whole screen.
   ** Make graphics colour changes a no-op instead of complaining. */
   if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
-#endif
 }
 
 /*
@@ -2119,13 +2105,9 @@ void emulate_gcol(int32 action, int32 colour, int32 tint) {
 ** otherwise the foreground colour is altered
 */
 int32 emulate_gcolrgb(int32 action, int32 background, int32 red, int32 green, int32 blue) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   /* Tektronix can't erase apart from the whole screen.
   ** Make graphics colour changes a no-op instead of complaining. */
   if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
-#endif
   return 0;
 }
 
@@ -2134,13 +2116,9 @@ int32 emulate_gcolrgb(int32 action, int32 background, int32 red, int32 green, in
 ** background colour to the colour number 'colnum'
 */
 void emulate_gcolnum(int32 action, int32 background, int32 colnum) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   /* Tektronix can't erase apart from the whole screen.
   ** Make graphics colour changes a no-op instead of complaining. */
   if (!matrixflags.tekenabled) error(ERR_NOGRAPHICS);
-#endif
 }
 
 /*
@@ -2201,67 +2179,7 @@ void emulate_defcolour(int32 colour, int32 red, int32 green, int32 blue) {
 ** Following are the functions that emulate graphics statements.
 */
 
-void emulate_move(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x, y);
-#endif
-}
-
-void emulate_moveby(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(DRAW_SOLIDLINE+MOVE_RELATIVE, x, y);
-#endif
-}
-
-void emulate_draw(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(DRAW_SOLIDLINE+DRAW_ABSOLUTE, x, y);
-#endif
-}
-
-void emulate_drawby(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(DRAW_SOLIDLINE+DRAW_RELATIVE, x, y);
-#endif
-}
-
-void emulate_line(int32 x1, int32 y1, int32 x2, int32 y2) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x1, y1);
-  emulate_plot(DRAW_SOLIDLINE+DRAW_ABSOLUTE, x2, y2);
-#endif
-}
-
-void emulate_point(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(PLOT_POINT+DRAW_ABSOLUTE, x, y);
-#endif
-}
-
-void emulate_pointby(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(PLOT_POINT+DRAW_RELATIVE, x, y);
-#endif
-}
-
 void emulate_ellipse(int32 x, int32 y, int32 majorlen, int32 minorlen, float64 angle, boolean isfilled) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   int32 slicew, shearx, maxy;
   
   float64 cosv, sinv;
@@ -2272,33 +2190,25 @@ void emulate_ellipse(int32 x, int32 y, int32 majorlen, int32 minorlen, float64 a
   slicew = (minorlen*majorlen)/maxy;
   shearx = (cosv*sinv*((majorlen*majorlen)-(minorlen*minorlen)))/maxy;
 
-  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x, y);	   /* Move to centre of ellipse */
-  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x+slicew, y);	/* Find a point on the circumference */
+  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x, y);        /* Move to centre of ellipse */
+  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x+slicew, y);      /* Find a point on the circumference */
   if (isfilled)
     emulate_plot(FILL_ELLIPSE+DRAW_ABSOLUTE, x+shearx, y+maxy);
   else {
     emulate_plot(PLOT_ELLIPSE+DRAW_ABSOLUTE, x+shearx, y+maxy);
   }
-#endif
 }
 
 void emulate_circle(int32 x, int32 y, int32 radius, boolean isfilled) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x, y);	   /* Move to centre of circle */
+  emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x, y);        /* Move to centre of circle */
   if (isfilled)
-    emulate_plot(FILL_CIRCLE+DRAW_ABSOLUTE, x-radius, y);	/* Plot to a point on the circumference */
+    emulate_plot(FILL_CIRCLE+DRAW_ABSOLUTE, x-radius, y);       /* Plot to a point on the circumference */
   else {
     emulate_plot(PLOT_CIRCLE+DRAW_ABSOLUTE, x-radius, y);
   }
-#endif
 }
 
 void emulate_drawrect(int32 x1, int32 y1, int32 width, int32 height, boolean isfilled) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x1, y1);
   if (isfilled)
     emulate_plot(FILL_RECTANGLE+DRAW_RELATIVE, width, height);
@@ -2308,49 +2218,24 @@ void emulate_drawrect(int32 x1, int32 y1, int32 width, int32 height, boolean isf
     emulate_plot(DRAW_SOLIDLINE+DRAW_RELATIVE, -width, 0);
     emulate_plot(DRAW_SOLIDLINE+DRAW_RELATIVE, 0, -height);
   }
-#endif
 }
 
 void emulate_moverect(int32 x1, int32 y1, int32 width, int32 height, int32 x2, int32 y2, boolean ismove) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   emulate_plot(DRAW_SOLIDLINE+MOVE_ABSOLUTE, x1, y1);
   emulate_plot(DRAW_SOLIDLINE+MOVE_RELATIVE, width, height);
-  if (ismove)	/* Move the area just marked */
+  if (ismove)   /* Move the area just marked */
     emulate_plot(MOVE_RECTANGLE, x2, y2);
   else {
     emulate_plot(COPY_RECTANGLE, x2, y2);
   }
-#endif
-}
-
-void emulate_fill(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(FLOOD_BACKGROUND+DRAW_ABSOLUTE, x, y);
-#endif
-}
-
-void emulate_fillby(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
-  emulate_plot(FLOOD_BACKGROUND+DRAW_RELATIVE, x, y);
-#endif
 }
 
 void emulate_origin(int32 x, int32 y) {
-#ifdef NOTEKGFX
-  error(ERR_NOGRAPHICS);
-#else
   emulate_vdu(VDU_ORIGIN);
   emulate_vdu(x & BYTEMASK);
   emulate_vdu((x>>BYTESHIFT) & BYTEMASK);
   emulate_vdu(y & BYTEMASK);
   emulate_vdu((y>>BYTESHIFT) & BYTEMASK);
-#endif
 }
 
 /*
@@ -2478,7 +2363,7 @@ void set_wintitle(char *title) {
 #if defined(_WIN32_WINNT) && _WIN32_WINNT >= 0x500
   SetConsoleTitleA(title);
 #elif defined(TARGET_UNIX)
-  printf("\x1B]0;%s\x1B\x5C", title);		// This is an xterm escape sequence, recognised by most terminals on Linux
+  printf("\x1B]0;%s\x1B\x5C", title);           // This is an xterm escape sequence, recognised by most terminals on Linux
 #endif
 #endif /* TARGET_MINIX */
 }
